Class: Google::Cloud::Dlp::V2::AdjustByImageFindings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

AdjustmentRule condition for image findings. This rule is silently ignored if the content being inspected is not an image.

Instance Attribute Summary collapse

Instance Attribute Details

#image_containment_type::Google::Cloud::Dlp::V2::ImageContainmentType

Returns Specifies the required spatial relationship between the bounding boxes of the target finding and the context infoType findings.

Returns:



186
187
188
189
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 186

class AdjustByImageFindings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#info_types::Array<::Google::Cloud::Dlp::V2::InfoType>

Returns A list of image-supported infoTypes—excluding document infoTypes—to be used as context for the adjustment rule. Sensitive Data Protection adjusts the likelihood of an image finding if its bounding box has the specified spatial relationship (defined by image_containment_type) with a finding of an infoType in this list.

For example, you can create a rule to adjust the likelihood of a US_PASSPORT finding if it is enclosed by a finding of OBJECT_TYPE/PERSON/PASSPORT. To configure this, set US_PASSPORT in InspectionRuleSet.info_types. Add an adjustment_rule with an adjust_by_image_findings.info_types that contains OBJECT_TYPE/PERSON/PASSPORT and image_containment_type set to encloses. In this case, the likelihood of the US_PASSPORT finding is adjusted, but the likelihood of the OBJECT_TYPE/PERSON/PASSPORT finding is not.

Returns:

  • (::Array<::Google::Cloud::Dlp::V2::InfoType>)

    A list of image-supported infoTypes—excluding document infoTypes—to be used as context for the adjustment rule. Sensitive Data Protection adjusts the likelihood of an image finding if its bounding box has the specified spatial relationship (defined by image_containment_type) with a finding of an infoType in this list.

    For example, you can create a rule to adjust the likelihood of a US_PASSPORT finding if it is enclosed by a finding of OBJECT_TYPE/PERSON/PASSPORT. To configure this, set US_PASSPORT in InspectionRuleSet.info_types. Add an adjustment_rule with an adjust_by_image_findings.info_types that contains OBJECT_TYPE/PERSON/PASSPORT and image_containment_type set to encloses. In this case, the likelihood of the US_PASSPORT finding is adjusted, but the likelihood of the OBJECT_TYPE/PERSON/PASSPORT finding is not.



186
187
188
189
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 186

class AdjustByImageFindings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#min_likelihood::Google::Cloud::Dlp::V2::Likelihood

Returns Required. Minimum likelihood of the adjust_by_image_findings.info_types finding. If the likelihood is lower than this value, Sensitive Data Protection doesn't adjust the likelihood of the InspectionRuleSet.info_types finding.

Returns:

  • (::Google::Cloud::Dlp::V2::Likelihood)

    Required. Minimum likelihood of the adjust_by_image_findings.info_types finding. If the likelihood is lower than this value, Sensitive Data Protection doesn't adjust the likelihood of the InspectionRuleSet.info_types finding.



186
187
188
189
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 186

class AdjustByImageFindings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end