Class: Google::Cloud::Dlp::V2::AdjustmentRule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Rule that specifies conditions when a certain infoType's finding details should be adjusted.

Instance Attribute Summary collapse

Instance Attribute Details

#adjust_by_image_findings::Google::Cloud::Dlp::V2::AdjustByImageFindings

Returns AdjustmentRule condition for image findings.

Note: The following fields are mutually exclusive: adjust_by_image_findings, adjust_by_matching_info_types. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::AdjustByImageFindings)

    AdjustmentRule condition for image findings.

    Note: The following fields are mutually exclusive: adjust_by_image_findings, adjust_by_matching_info_types. If a field in that set is populated, all other fields in the set will automatically be cleared.



206
207
208
209
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 206

class AdjustmentRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#adjust_by_matching_info_types::Google::Cloud::Dlp::V2::AdjustByMatchingInfoTypes

Returns Set of infoTypes for which findings would affect this rule.

Note: The following fields are mutually exclusive: adjust_by_matching_info_types, adjust_by_image_findings. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::AdjustByMatchingInfoTypes)

    Set of infoTypes for which findings would affect this rule.

    Note: The following fields are mutually exclusive: adjust_by_matching_info_types, adjust_by_image_findings. If a field in that set is populated, all other fields in the set will automatically be cleared.



206
207
208
209
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 206

class AdjustmentRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#likelihood_adjustment::Google::Cloud::Dlp::V2::CustomInfoType::DetectionRule::LikelihoodAdjustment

Returns Likelihood adjustment to apply to the infoType.

Returns:



206
207
208
209
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 206

class AdjustmentRule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end