Class: Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::CategoricalStatsResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::CategoricalStatsResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Result of the categorical stats computation.
Defined Under Namespace
Classes: CategoricalStatsHistogramBucket
Instance Attribute Summary collapse
-
#value_frequency_histogram_buckets ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::CategoricalStatsResult::CategoricalStatsHistogramBucket>
Histogram of value frequencies in the column.
Instance Attribute Details
#value_frequency_histogram_buckets ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::CategoricalStatsResult::CategoricalStatsHistogramBucket>
Returns Histogram of value frequencies in the column.
2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2276 class CategoricalStatsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Histogram of value frequencies in the column. # @!attribute [rw] value_frequency_lower_bound # @return [::Integer] # Lower bound on the value frequency of the values in this bucket. # @!attribute [rw] value_frequency_upper_bound # @return [::Integer] # Upper bound on the value frequency of the values in this bucket. # @!attribute [rw] bucket_size # @return [::Integer] # Total number of values in this bucket. # @!attribute [rw] bucket_values # @return [::Array<::Google::Cloud::Dlp::V2::ValueFrequency>] # Sample of value frequencies in this bucket. The total number of # values returned per bucket is capped at 20. # @!attribute [rw] bucket_value_count # @return [::Integer] # Total number of distinct values in this bucket. class CategoricalStatsHistogramBucket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |