Class: Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KAnonymityResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Result of the k-anonymity computation.

Defined Under Namespace

Classes: KAnonymityEquivalenceClass, KAnonymityHistogramBucket

Instance Attribute Summary collapse

Instance Attribute Details

#equivalence_class_histogram_buckets::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KAnonymityResult::KAnonymityHistogramBucket>

Returns Histogram of k-anonymity equivalence classes.

Returns:



2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2307

class KAnonymityResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The set of columns' values that share the same ldiversity value
  # @!attribute [rw] quasi_ids_values
  #   @return [::Array<::Google::Cloud::Dlp::V2::Value>]
  #     Set of values defining the equivalence class. One value per
  #     quasi-identifier column in the original KAnonymity metric message.
  #     The order is always the same as the original request.
  # @!attribute [rw] equivalence_class_size
  #   @return [::Integer]
  #     Size of the equivalence class, for example number of rows with the
  #     above set of values.
  class KAnonymityEquivalenceClass
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Histogram of k-anonymity equivalence classes.
  # @!attribute [rw] equivalence_class_size_lower_bound
  #   @return [::Integer]
  #     Lower bound on the size of the equivalence classes in this bucket.
  # @!attribute [rw] equivalence_class_size_upper_bound
  #   @return [::Integer]
  #     Upper bound on the size of the equivalence classes in this bucket.
  # @!attribute [rw] bucket_size
  #   @return [::Integer]
  #     Total number of equivalence classes in this bucket.
  # @!attribute [rw] bucket_values
  #   @return [::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KAnonymityResult::KAnonymityEquivalenceClass>]
  #     Sample of equivalence classes in this bucket. The total number of
  #     classes returned per bucket is capped at 20.
  # @!attribute [rw] bucket_value_count
  #   @return [::Integer]
  #     Total number of distinct equivalence classes in this bucket.
  class KAnonymityHistogramBucket
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end