Class: Google::Cloud::Dlp::V2::BatchContentItem

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Represents a batch of content to inspect or redact.

Instance Attribute Summary collapse

Instance Attribute Details

#string_value_batch::Google::Cloud::Dlp::V2::StringValueBatch

Returns Optional. Represents a batch of string values to inspect or redact.

Returns:



572
573
574
575
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 572

class BatchContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end