Class: Google::Cloud::Dlp::V2::ByteContentItem

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Container for bytes to inspect or redact.

Defined Under Namespace

Modules: BytesType

Instance Attribute Summary collapse

Instance Attribute Details

#data::String

Returns Content data to inspect or redact.

Returns:

  • (::String)

    Content data to inspect or redact.



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 406

class ByteContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of data being sent for inspection. To learn more, see
  # [Supported file
  # types](https://cloud.google.com/sensitive-data-protection/docs/supported-file-types).
  #
  # Only the first frame of each multiframe image is inspected. Metadata and
  # other frames aren't inspected.
  module BytesType
    # Unused
    BYTES_TYPE_UNSPECIFIED = 0

    # Any image type.
    IMAGE = 6

    # jpeg
    IMAGE_JPEG = 1

    # bmp
    IMAGE_BMP = 2

    # png
    IMAGE_PNG = 3

    # svg
    IMAGE_SVG = 4

    # plain text
    TEXT_UTF8 = 5

    # docx, docm, dotx, dotm
    WORD_DOCUMENT = 7

    # pdf
    PDF = 8

    # pptx, pptm, potx, potm, pot
    POWERPOINT_DOCUMENT = 9

    # xlsx, xlsm, xltx, xltm
    EXCEL_DOCUMENT = 10

    # avro
    AVRO = 11

    # csv
    CSV = 12

    # tsv
    TSV = 13

    # Audio file types. Only used for profiling.
    AUDIO = 15

    # Video file types. Only used for profiling.
    VIDEO = 16

    # Executable file types. Only used for profiling.
    EXECUTABLE = 17

    # AI model file types. Only used for profiling.
    AI_MODEL = 18
  end
end

#type::Google::Cloud::Dlp::V2::ByteContentItem::BytesType

Returns The type of data stored in the bytes string. Default will be TEXT_UTF8.

Returns:



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 406

class ByteContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of data being sent for inspection. To learn more, see
  # [Supported file
  # types](https://cloud.google.com/sensitive-data-protection/docs/supported-file-types).
  #
  # Only the first frame of each multiframe image is inspected. Metadata and
  # other frames aren't inspected.
  module BytesType
    # Unused
    BYTES_TYPE_UNSPECIFIED = 0

    # Any image type.
    IMAGE = 6

    # jpeg
    IMAGE_JPEG = 1

    # bmp
    IMAGE_BMP = 2

    # png
    IMAGE_PNG = 3

    # svg
    IMAGE_SVG = 4

    # plain text
    TEXT_UTF8 = 5

    # docx, docm, dotx, dotm
    WORD_DOCUMENT = 7

    # pdf
    PDF = 8

    # pptx, pptm, potx, potm, pot
    POWERPOINT_DOCUMENT = 9

    # xlsx, xlsm, xltx, xltm
    EXCEL_DOCUMENT = 10

    # avro
    AVRO = 11

    # csv
    CSV = 12

    # tsv
    TSV = 13

    # Audio file types. Only used for profiling.
    AUDIO = 15

    # Video file types. Only used for profiling.
    VIDEO = 16

    # Executable file types. Only used for profiling.
    EXECUTABLE = 17

    # AI model file types. Only used for profiling.
    AI_MODEL = 18
  end
end