Class: Google::Cloud::Dlp::V2::CharsToIgnore

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Characters to skip when doing deidentification of a value. These will be left alone and skipped.

Defined Under Namespace

Modules: CommonCharsToIgnore

Instance Attribute Summary collapse

Instance Attribute Details

#characters_to_skip::String

Returns Characters to not transform when masking.

Note: The following fields are mutually exclusive: characters_to_skip, common_characters_to_ignore. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Characters to not transform when masking.

    Note: The following fields are mutually exclusive: characters_to_skip, common_characters_to_ignore. If a field in that set is populated, all other fields in the set will automatically be cleared.



2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2993

class CharsToIgnore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Convenience enum for indicating common characters to not transform.
  module CommonCharsToIgnore
    # Unused.
    COMMON_CHARS_TO_IGNORE_UNSPECIFIED = 0

    # 0-9
    NUMERIC = 1

    # A-Z
    ALPHA_UPPER_CASE = 2

    # a-z
    ALPHA_LOWER_CASE = 3

    # US Punctuation, one of !"#$%&'()*+,-./:;<=>?@[\]^_`{|}~
    PUNCTUATION = 4

    # Whitespace character, one of [ \t\n\x0B\f\r]
    WHITESPACE = 5
  end
end

#common_characters_to_ignore::Google::Cloud::Dlp::V2::CharsToIgnore::CommonCharsToIgnore

Returns Common characters to not transform when masking. Useful to avoid removing punctuation.

Note: The following fields are mutually exclusive: common_characters_to_ignore, characters_to_skip. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::CharsToIgnore::CommonCharsToIgnore)

    Common characters to not transform when masking. Useful to avoid removing punctuation.

    Note: The following fields are mutually exclusive: common_characters_to_ignore, characters_to_skip. If a field in that set is populated, all other fields in the set will automatically be cleared.



2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2993

class CharsToIgnore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Convenience enum for indicating common characters to not transform.
  module CommonCharsToIgnore
    # Unused.
    COMMON_CHARS_TO_IGNORE_UNSPECIFIED = 0

    # 0-9
    NUMERIC = 1

    # A-Z
    ALPHA_UPPER_CASE = 2

    # a-z
    ALPHA_LOWER_CASE = 3

    # US Punctuation, one of !"#$%&'()*+,-./:;<=>?@[\]^_`{|}~
    PUNCTUATION = 4

    # Whitespace character, one of [ \t\n\x0B\f\r]
    WHITESPACE = 5
  end
end