Class: Google::Cloud::Dlp::V2::CloudSqlProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Cloud SQL connection properties.

Defined Under Namespace

Modules: DatabaseEngine

Instance Attribute Summary collapse

Instance Attribute Details

#cloud_sql_iam::Google::Cloud::Dlp::V2::CloudSqlIamCredential

Returns Built-in IAM authentication (must be configured in Cloud SQL).

Note: The following fields are mutually exclusive: cloud_sql_iam, username_password. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::CloudSqlIamCredential)

    Built-in IAM authentication (must be configured in Cloud SQL).

    Note: The following fields are mutually exclusive: cloud_sql_iam, username_password. If a field in that set is populated, all other fields in the set will automatically be cleared.



8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8491

class CloudSqlProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Database engine of a Cloud SQL instance.
  # New values may be added over time.
  module DatabaseEngine
    # An engine that is not currently supported by Sensitive Data Protection.
    DATABASE_ENGINE_UNKNOWN = 0

    # Cloud SQL for MySQL instance.
    DATABASE_ENGINE_MYSQL = 1

    # Cloud SQL for PostgreSQL instance.
    DATABASE_ENGINE_POSTGRES = 2
  end
end

#connection_name::String

Returns Optional. Immutable. The Cloud SQL instance for which the connection is defined. Only one connection per instance is allowed. This can only be set at creation time, and cannot be updated.

It is an error to use a connection_name from different project or region than the one that holds the connection. For example, a Connection resource for Cloud SQL connection_name project-id:us-central1:sql-instance must be created under the parent projects/project-id/locations/us-central1.

Returns:

  • (::String)

    Optional. Immutable. The Cloud SQL instance for which the connection is defined. Only one connection per instance is allowed. This can only be set at creation time, and cannot be updated.

    It is an error to use a connection_name from different project or region than the one that holds the connection. For example, a Connection resource for Cloud SQL connection_name project-id:us-central1:sql-instance must be created under the parent projects/project-id/locations/us-central1



8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8491

class CloudSqlProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Database engine of a Cloud SQL instance.
  # New values may be added over time.
  module DatabaseEngine
    # An engine that is not currently supported by Sensitive Data Protection.
    DATABASE_ENGINE_UNKNOWN = 0

    # Cloud SQL for MySQL instance.
    DATABASE_ENGINE_MYSQL = 1

    # Cloud SQL for PostgreSQL instance.
    DATABASE_ENGINE_POSTGRES = 2
  end
end

#database_engine::Google::Cloud::Dlp::V2::CloudSqlProperties::DatabaseEngine

Returns Required. The database engine used by the Cloud SQL instance that this connection configures.

Returns:



8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8491

class CloudSqlProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Database engine of a Cloud SQL instance.
  # New values may be added over time.
  module DatabaseEngine
    # An engine that is not currently supported by Sensitive Data Protection.
    DATABASE_ENGINE_UNKNOWN = 0

    # Cloud SQL for MySQL instance.
    DATABASE_ENGINE_MYSQL = 1

    # Cloud SQL for PostgreSQL instance.
    DATABASE_ENGINE_POSTGRES = 2
  end
end

#max_connections::Integer

Returns Required. The DLP API will limit its connections to max_connections. Must be 2 or greater.

Returns:

  • (::Integer)

    Required. The DLP API will limit its connections to max_connections. Must be 2 or greater.



8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8491

class CloudSqlProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Database engine of a Cloud SQL instance.
  # New values may be added over time.
  module DatabaseEngine
    # An engine that is not currently supported by Sensitive Data Protection.
    DATABASE_ENGINE_UNKNOWN = 0

    # Cloud SQL for MySQL instance.
    DATABASE_ENGINE_MYSQL = 1

    # Cloud SQL for PostgreSQL instance.
    DATABASE_ENGINE_POSTGRES = 2
  end
end

#username_password::Google::Cloud::Dlp::V2::SecretManagerCredential

Returns A username and password stored in Secret Manager.

Note: The following fields are mutually exclusive: username_password, cloud_sql_iam. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::SecretManagerCredential)

    A username and password stored in Secret Manager.

    Note: The following fields are mutually exclusive: username_password, cloud_sql_iam. If a field in that set is populated, all other fields in the set will automatically be cleared.



8491
8492
8493
8494
8495
8496
8497
8498
8499
8500
8501
8502
8503
8504
8505
8506
8507
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8491

class CloudSqlProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Database engine of a Cloud SQL instance.
  # New values may be added over time.
  module DatabaseEngine
    # An engine that is not currently supported by Sensitive Data Protection.
    DATABASE_ENGINE_UNKNOWN = 0

    # Cloud SQL for MySQL instance.
    DATABASE_ENGINE_MYSQL = 1

    # Cloud SQL for PostgreSQL instance.
    DATABASE_ENGINE_POSTGRES = 2
  end
end