Class: Google::Cloud::Dlp::V2::ContentItem

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Type of content to inspect.

Instance Attribute Summary collapse

Instance Attribute Details

#batch_content_item::Google::Cloud::Dlp::V2::BatchContentItem

Returns Represents a batch of items to inspect.

Note: The following fields are mutually exclusive: batch_content_item, value, table, byte_item, conversation. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::BatchContentItem)

    Represents a batch of items to inspect.

    Note: The following fields are mutually exclusive: batch_content_item, value, table, byte_item, conversation. If a field in that set is populated, all other fields in the set will automatically be cleared.



506
507
508
509
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 506

class ContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#byte_item::Google::Cloud::Dlp::V2::ByteContentItem

Returns Content data to inspect or redact. Replaces type and data.

Note: The following fields are mutually exclusive: byte_item, value, table, conversation, batch_content_item. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::ByteContentItem)

    Content data to inspect or redact. Replaces type and data.

    Note: The following fields are mutually exclusive: byte_item, value, table, conversation, batch_content_item. If a field in that set is populated, all other fields in the set will automatically be cleared.



506
507
508
509
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 506

class ContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#content_metadata::Google::Cloud::Dlp::V2::ContentMetadata

Returns User provided metadata for the content.

Returns:



506
507
508
509
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 506

class ContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#conversation::Google::Cloud::Dlp::V2::Conversation

Returns Represents a conversation (either complete or a slice). It is assumed that all included messages are contiguous and ordered in chronological order.

Note: The following fields are mutually exclusive: conversation, value, table, byte_item, batch_content_item. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::Conversation)

    Represents a conversation (either complete or a slice). It is assumed that all included messages are contiguous and ordered in chronological order.

    Note: The following fields are mutually exclusive: conversation, value, table, byte_item, batch_content_item. If a field in that set is populated, all other fields in the set will automatically be cleared.



506
507
508
509
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 506

class ContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#table::Google::Cloud::Dlp::V2::Table

Returns Structured content for inspection. See https://cloud.google.com/sensitive-data-protection/docs/inspecting-text#inspecting_a_table to learn more.

Note: The following fields are mutually exclusive: table, value, byte_item, conversation, batch_content_item. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



506
507
508
509
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 506

class ContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::String

Returns String data to inspect or redact.

Note: The following fields are mutually exclusive: value, table, byte_item, conversation, batch_content_item. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    String data to inspect or redact.

    Note: The following fields are mutually exclusive: value, table, byte_item, conversation, batch_content_item. If a field in that set is populated, all other fields in the set will automatically be cleared.



506
507
508
509
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 506

class ContentItem
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end