Class: Google::Cloud::Dlp::V2::ContentLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ContentLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Precise location of the finding within a document, record, image, or metadata container.
Instance Attribute Summary collapse
-
#batch_content_location ⇒ ::Google::Cloud::Dlp::V2::BatchContentLocation
Location within a batch of content.
-
#container_name ⇒ ::String
Name of the container where the finding is located.
-
#container_timestamp ⇒ ::Google::Protobuf::Timestamp
Finding container modification timestamp, if applicable.
-
#container_version ⇒ ::String
Finding container version, if available ("generation" for Cloud Storage).
-
#conversation_location ⇒ ::Google::Cloud::Dlp::V2::ConversationLocation
Location within a conversation.
-
#document_location ⇒ ::Google::Cloud::Dlp::V2::DocumentLocation
Location data for document files.
-
#image_location ⇒ ::Google::Cloud::Dlp::V2::ImageLocation
Location within an image's pixels.
-
#metadata_location ⇒ ::Google::Cloud::Dlp::V2::MetadataLocation
Location within the metadata for inspected content.
-
#record_location ⇒ ::Google::Cloud::Dlp::V2::RecordLocation
Location within a row or record of a database table.
Instance Attribute Details
#batch_content_location ⇒ ::Google::Cloud::Dlp::V2::BatchContentLocation
Returns Location within a batch of content.
Note: The following fields are mutually exclusive: batch_content_location, record_location, image_location, document_location, metadata_location, conversation_location. If a field in that set is populated, all other fields in the set will automatically be cleared.
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#container_name ⇒ ::String
Returns Name of the container where the finding is located. The top level name is the source file name or table name. Names of some common storage containers are formatted as follows:
- BigQuery tables:
{project_id}:{dataset_id}.{table_id} - Cloud Storage files:
gs://{bucket}/{path} - Datastore namespace: {namespace}
Nested names could be absent if the embedded object has no string identifier (for example, an image contained within a document).
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#container_timestamp ⇒ ::Google::Protobuf::Timestamp
Returns Finding container modification timestamp, if applicable. For Cloud Storage, this field contains the last file modification timestamp. For a BigQuery table, this field contains the last_modified_time property. For Datastore, this field isn't populated.
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#container_version ⇒ ::String
Returns Finding container version, if available ("generation" for Cloud Storage).
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#conversation_location ⇒ ::Google::Cloud::Dlp::V2::ConversationLocation
Returns Location within a conversation.
Note: The following fields are mutually exclusive: conversation_location, record_location, image_location, document_location, metadata_location, batch_content_location. If a field in that set is populated, all other fields in the set will automatically be cleared.
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#document_location ⇒ ::Google::Cloud::Dlp::V2::DocumentLocation
Returns Location data for document files.
Note: The following fields are mutually exclusive: document_location, record_location, image_location, metadata_location, conversation_location, batch_content_location. If a field in that set is populated, all other fields in the set will automatically be cleared.
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image_location ⇒ ::Google::Cloud::Dlp::V2::ImageLocation
Returns Location within an image's pixels.
Note: The following fields are mutually exclusive: image_location, record_location, document_location, metadata_location, conversation_location, batch_content_location. If a field in that set is populated, all other fields in the set will automatically be cleared.
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metadata_location ⇒ ::Google::Cloud::Dlp::V2::MetadataLocation
Returns Location within the metadata for inspected content.
Note: The following fields are mutually exclusive: metadata_location, record_location, image_location, document_location, conversation_location, batch_content_location. If a field in that set is populated, all other fields in the set will automatically be cleared.
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#record_location ⇒ ::Google::Cloud::Dlp::V2::RecordLocation
Returns Location within a row or record of a database table.
Note: The following fields are mutually exclusive: record_location, image_location, document_location, metadata_location, conversation_location, batch_content_location. If a field in that set is populated, all other fields in the set will automatically be cleared.
793 794 795 796 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 793 class ContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |