Class: Google::Cloud::Dlp::V2::Conversation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Complete conversation or slice of a conversation. It is assumed that all included messages are contiguous and ordered in chronological order.

Instance Attribute Summary collapse

Instance Attribute Details

#messages::Array<::Google::Cloud::Dlp::V2::ConversationMessage>

Returns Messages exchanged within this conversation. The maximum number of messages allowed is 50k. The order of the messages is assumed to be chronological and will be used to index findings in the response.

Returns:

  • (::Array<::Google::Cloud::Dlp::V2::ConversationMessage>)

    Messages exchanged within this conversation. The maximum number of messages allowed is 50k. The order of the messages is assumed to be chronological and will be used to index findings in the response.



529
530
531
532
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 529

class Conversation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end