Class: Google::Cloud::Dlp::V2::ConversationMessage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Single message in a conversation.

Defined Under Namespace

Modules: MessageType

Instance Attribute Summary collapse

Instance Attribute Details

#content::String

Returns The contents of this message.

Returns:

  • (::String)

    The contents of this message.



549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 549

class ConversationMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of message.
  # New values may be added in the future.
  module MessageType
    # Unused.
    MESSAGE_TYPE_UNSPECIFIED = 0

    # Message contains content to be inspected.
    CONTENT = 1

    # Message contains context only and will not have findings reported from
    # it during inspection or redacted from it during de-identification.
    CONTEXT = 2
  end
end

#message_type::Google::Cloud::Dlp::V2::ConversationMessage::MessageType

Returns The type of message.



549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 549

class ConversationMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of message.
  # New values may be added in the future.
  module MessageType
    # Unused.
    MESSAGE_TYPE_UNSPECIFIED = 0

    # Message contains content to be inspected.
    CONTENT = 1

    # Message contains context only and will not have findings reported from
    # it during inspection or redacted from it during de-identification.
    CONTEXT = 2
  end
end

#participant_id::String

Returns Optional. The identifier of the participant, for example 'test-user' or 'gemini'. The participant ID can contain lowercase letters, numbers, and hyphens; that is, it must match the regular expression: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$. The maximum length is 63 characters.

Returns:

  • (::String)

    Optional. The identifier of the participant, for example 'test-user' or 'gemini'. The participant ID can contain lowercase letters, numbers, and hyphens; that is, it must match the regular expression: ^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$. The maximum length is 63 characters.



549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 549

class ConversationMessage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of message.
  # New values may be added in the future.
  module MessageType
    # Unused.
    MESSAGE_TYPE_UNSPECIFIED = 0

    # Message contains content to be inspected.
    CONTENT = 1

    # Message contains context only and will not have findings reported from
    # it during inspection or redacted from it during de-identification.
    CONTEXT = 2
  end
end