Class: Google::Cloud::Dlp::V2::DataProfileAction::PubSubNotification
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::DataProfileAction::PubSubNotification
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Send a Pub/Sub message into the given Pub/Sub topic to connect other
systems to data profile generation. The message payload data will
be the byte serialization of DataProfilePubSubMessage.
Defined Under Namespace
Modules: DetailLevel
Instance Attribute Summary collapse
-
#detail_of_message ⇒ ::Google::Cloud::Dlp::V2::DataProfileAction::PubSubNotification::DetailLevel
How much data to include in the Pub/Sub message.
-
#event ⇒ ::Google::Cloud::Dlp::V2::DataProfileAction::EventType
The type of event that triggers a Pub/Sub.
-
#pubsub_condition ⇒ ::Google::Cloud::Dlp::V2::DataProfilePubSubCondition
Conditions (e.g., data risk or sensitivity level) for triggering a Pub/Sub.
-
#topic ⇒ ::String
Cloud Pub/Sub topic to send notifications to.
Instance Attribute Details
#detail_of_message ⇒ ::Google::Cloud::Dlp::V2::DataProfileAction::PubSubNotification::DetailLevel
Returns How much data to include in the Pub/Sub message. If the user wishes to limit the size of the message, they can use resource_name and fetch the profile fields they wish to. Per table profile (not per column).
4814 4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 4814 class PubSubNotification include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The levels of detail that can be included in the Pub/Sub message. module DetailLevel # Unused. DETAIL_LEVEL_UNSPECIFIED = 0 # The full table data profile. TABLE_PROFILE = 1 # The name of the profiled resource. RESOURCE_NAME = 2 # The full file store data profile. FILE_STORE_PROFILE = 3 end end |
#event ⇒ ::Google::Cloud::Dlp::V2::DataProfileAction::EventType
Returns The type of event that triggers a Pub/Sub. At most one
PubSubNotification per EventType is permitted.
4814 4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 4814 class PubSubNotification include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The levels of detail that can be included in the Pub/Sub message. module DetailLevel # Unused. DETAIL_LEVEL_UNSPECIFIED = 0 # The full table data profile. TABLE_PROFILE = 1 # The name of the profiled resource. RESOURCE_NAME = 2 # The full file store data profile. FILE_STORE_PROFILE = 3 end end |
#pubsub_condition ⇒ ::Google::Cloud::Dlp::V2::DataProfilePubSubCondition
Returns Conditions (e.g., data risk or sensitivity level) for triggering a Pub/Sub.
4814 4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 4814 class PubSubNotification include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The levels of detail that can be included in the Pub/Sub message. module DetailLevel # Unused. DETAIL_LEVEL_UNSPECIFIED = 0 # The full table data profile. TABLE_PROFILE = 1 # The name of the profiled resource. RESOURCE_NAME = 2 # The full file store data profile. FILE_STORE_PROFILE = 3 end end |
#topic ⇒ ::String
Returns Cloud Pub/Sub topic to send notifications to. Format is projects/{project}/topics/{topic}.
4814 4815 4816 4817 4818 4819 4820 4821 4822 4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 4814 class PubSubNotification include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The levels of detail that can be included in the Pub/Sub message. module DetailLevel # Unused. DETAIL_LEVEL_UNSPECIFIED = 0 # The full table data profile. TABLE_PROFILE = 1 # The name of the profiled resource. RESOURCE_NAME = 2 # The full file store data profile. FILE_STORE_PROFILE = 3 end end |