Class: Google::Cloud::Dlp::V2::DataRiskLevel

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Score is a summary of all elements in the data profile. A higher number means more risk.

Defined Under Namespace

Modules: DataRiskLevelScore

Instance Attribute Summary collapse

Instance Attribute Details

#score::Google::Cloud::Dlp::V2::DataRiskLevel::DataRiskLevelScore

Returns The score applied to the resource.

Returns:



7366
7367
7368
7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7366

class DataRiskLevel
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Various score levels for resources.
  module DataRiskLevelScore
    # Unused.
    RISK_SCORE_UNSPECIFIED = 0

    # Low risk - Lower indication of sensitive data that appears to have
    # additional access restrictions in place or no indication of sensitive
    # data found.
    RISK_LOW = 10

    # Unable to determine risk.
    RISK_UNKNOWN = 12

    # Medium risk - Sensitive data may be present but additional access or fine
    # grain access restrictions appear to be present.  Consider limiting
    # access even further or transform data to mask.
    RISK_MODERATE = 20

    # High risk – SPII may be present. Access controls may include public
    # ACLs. Exfiltration of data may lead to user data loss. Re-identification
    # of users may be possible. Consider limiting usage and or removing SPII.
    RISK_HIGH = 30
  end
end