Class: Google::Cloud::Dlp::V2::DeidentifyDataSourceDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

The results of a Deidentify action from an inspect job.

Defined Under Namespace

Classes: RequestedDeidentifyOptions

Instance Attribute Summary collapse

Instance Attribute Details

#deidentify_stats::Google::Cloud::Dlp::V2::DeidentifyDataSourceStats

Returns Stats about the de-identification operation.

Returns:



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1520

class DeidentifyDataSourceDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # De-identification options.
  # @!attribute [rw] snapshot_deidentify_template
  #   @return [::Google::Cloud::Dlp::V2::DeidentifyTemplate]
  #     Snapshot of the state of the `DeidentifyTemplate` from the
  #     {::Google::Cloud::Dlp::V2::Action::Deidentify Deidentify} action at the time
  #     this job was run.
  # @!attribute [rw] snapshot_structured_deidentify_template
  #   @return [::Google::Cloud::Dlp::V2::DeidentifyTemplate]
  #     Snapshot of the state of the structured `DeidentifyTemplate` from the
  #     `Deidentify` action at the time this job was run.
  # @!attribute [rw] snapshot_image_redact_template
  #   @return [::Google::Cloud::Dlp::V2::DeidentifyTemplate]
  #     Snapshot of the state of the image transformation `DeidentifyTemplate`
  #     from the `Deidentify` action at the time this job was run.
  class RequestedDeidentifyOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#requested_options::Google::Cloud::Dlp::V2::DeidentifyDataSourceDetails::RequestedDeidentifyOptions

Returns De-identification config used for the request.

Returns:



1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1520

class DeidentifyDataSourceDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # De-identification options.
  # @!attribute [rw] snapshot_deidentify_template
  #   @return [::Google::Cloud::Dlp::V2::DeidentifyTemplate]
  #     Snapshot of the state of the `DeidentifyTemplate` from the
  #     {::Google::Cloud::Dlp::V2::Action::Deidentify Deidentify} action at the time
  #     this job was run.
  # @!attribute [rw] snapshot_structured_deidentify_template
  #   @return [::Google::Cloud::Dlp::V2::DeidentifyTemplate]
  #     Snapshot of the state of the structured `DeidentifyTemplate` from the
  #     `Deidentify` action at the time this job was run.
  # @!attribute [rw] snapshot_image_redact_template
  #   @return [::Google::Cloud::Dlp::V2::DeidentifyTemplate]
  #     Snapshot of the state of the image transformation `DeidentifyTemplate`
  #     from the `Deidentify` action at the time this job was run.
  class RequestedDeidentifyOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end