Class: Google::Cloud::Dlp::V2::DiscoveryBigQueryConditions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Requirements that must be true before a table is scanned in discovery for the first time. There is an AND relationship between the top-level attributes. Additionally, minimum conditions with an OR relationship that must be met before Cloud DLP scans a table can be set (like a minimum row count or a minimum table age).

Defined Under Namespace

Classes: OrConditions

Instance Attribute Summary collapse

Instance Attribute Details

#created_after::Google::Protobuf::Timestamp

Returns BigQuery table must have been created after this date. Used to avoid backfilling.

Returns:



5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
5376
5377
5378
5379
5380
5381
5382
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5364

class DiscoveryBigQueryConditions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # There is an OR relationship between these attributes. They are used to
  # determine if a table should be scanned or not in Discovery.
  # @!attribute [rw] min_row_count
  #   @return [::Integer]
  #     Minimum number of rows that should be present before Cloud DLP
  #     profiles a table
  # @!attribute [rw] min_age
  #   @return [::Google::Protobuf::Duration]
  #     Minimum age a table must have before Cloud DLP can profile it. Value must
  #     be 1 hour or greater.
  class OrConditions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#or_conditions::Google::Cloud::Dlp::V2::DiscoveryBigQueryConditions::OrConditions

Returns At least one of the conditions must be true for a table to be scanned.

Returns:



5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
5376
5377
5378
5379
5380
5381
5382
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5364

class DiscoveryBigQueryConditions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # There is an OR relationship between these attributes. They are used to
  # determine if a table should be scanned or not in Discovery.
  # @!attribute [rw] min_row_count
  #   @return [::Integer]
  #     Minimum number of rows that should be present before Cloud DLP
  #     profiles a table
  # @!attribute [rw] min_age
  #   @return [::Google::Protobuf::Duration]
  #     Minimum age a table must have before Cloud DLP can profile it. Value must
  #     be 1 hour or greater.
  class OrConditions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#type_collection::Google::Cloud::Dlp::V2::BigQueryTableTypeCollection

Returns Restrict discovery to categories of table types.

Note: The following fields are mutually exclusive: type_collection, types. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::BigQueryTableTypeCollection)

    Restrict discovery to categories of table types.

    Note: The following fields are mutually exclusive: type_collection, types. If a field in that set is populated, all other fields in the set will automatically be cleared.



5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
5376
5377
5378
5379
5380
5381
5382
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5364

class DiscoveryBigQueryConditions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # There is an OR relationship between these attributes. They are used to
  # determine if a table should be scanned or not in Discovery.
  # @!attribute [rw] min_row_count
  #   @return [::Integer]
  #     Minimum number of rows that should be present before Cloud DLP
  #     profiles a table
  # @!attribute [rw] min_age
  #   @return [::Google::Protobuf::Duration]
  #     Minimum age a table must have before Cloud DLP can profile it. Value must
  #     be 1 hour or greater.
  class OrConditions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#types::Google::Cloud::Dlp::V2::BigQueryTableTypes

Returns Restrict discovery to specific table types.

Note: The following fields are mutually exclusive: types, type_collection. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::BigQueryTableTypes)

    Restrict discovery to specific table types.

    Note: The following fields are mutually exclusive: types, type_collection. If a field in that set is populated, all other fields in the set will automatically be cleared.



5364
5365
5366
5367
5368
5369
5370
5371
5372
5373
5374
5375
5376
5377
5378
5379
5380
5381
5382
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5364

class DiscoveryBigQueryConditions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # There is an OR relationship between these attributes. They are used to
  # determine if a table should be scanned or not in Discovery.
  # @!attribute [rw] min_row_count
  #   @return [::Integer]
  #     Minimum number of rows that should be present before Cloud DLP
  #     profiles a table
  # @!attribute [rw] min_age
  #   @return [::Google::Protobuf::Duration]
  #     Minimum age a table must have before Cloud DLP can profile it. Value must
  #     be 1 hour or greater.
  class OrConditions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end