Class: Google::Cloud::Dlp::V2::DiscoveryCloudSqlConditions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Requirements that must be true before a table is profiled for the first time.

Defined Under Namespace

Modules: DatabaseEngine, DatabaseResourceType

Instance Attribute Summary collapse

Instance Attribute Details

#database_engines::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudSqlConditions::DatabaseEngine>

Returns Optional. Database engines that should be profiled. Optional. Defaults to ALL_SUPPORTED_DATABASE_ENGINES if unspecified.

Returns:



5588
5589
5590
5591
5592
5593
5594
5595
5596
5597
5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5588

class DiscoveryCloudSqlConditions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engines that should be profiled.
  module DatabaseEngine
    # Unused.
    DATABASE_ENGINE_UNSPECIFIED = 0

    # Include all supported database engines.
    ALL_SUPPORTED_DATABASE_ENGINES = 1

    # MySQL database.
    MYSQL = 2

    # PostgreSQL database.
    POSTGRES = 3
  end

  # Cloud SQL database resource types. New values can be added at a later time.
  module DatabaseResourceType
    # Unused.
    DATABASE_RESOURCE_TYPE_UNSPECIFIED = 0

    # Includes database resource types that become supported at a later time.
    DATABASE_RESOURCE_TYPE_ALL_SUPPORTED_TYPES = 1

    # Tables.
    DATABASE_RESOURCE_TYPE_TABLE = 2
  end
end

#types::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudSqlConditions::DatabaseResourceType>

Returns Data profiles will only be generated for the database resource types specified in this field. If not specified, defaults to [DATABASE_RESOURCE_TYPE_ALL_SUPPORTED_TYPES].

Returns:



5588
5589
5590
5591
5592
5593
5594
5595
5596
5597
5598
5599
5600
5601
5602
5603
5604
5605
5606
5607
5608
5609
5610
5611
5612
5613
5614
5615
5616
5617
5618
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5588

class DiscoveryCloudSqlConditions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The database engines that should be profiled.
  module DatabaseEngine
    # Unused.
    DATABASE_ENGINE_UNSPECIFIED = 0

    # Include all supported database engines.
    ALL_SUPPORTED_DATABASE_ENGINES = 1

    # MySQL database.
    MYSQL = 2

    # PostgreSQL database.
    POSTGRES = 3
  end

  # Cloud SQL database resource types. New values can be added at a later time.
  module DatabaseResourceType
    # Unused.
    DATABASE_RESOURCE_TYPE_UNSPECIFIED = 0

    # Includes database resource types that become supported at a later time.
    DATABASE_RESOURCE_TYPE_ALL_SUPPORTED_TYPES = 1

    # Tables.
    DATABASE_RESOURCE_TYPE_TABLE = 2
  end
end