Class: Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
How frequently to modify the profile when the table's schema is modified.
Defined Under Namespace
Modules: CloudSqlSchemaModification
Instance Attribute Summary collapse
-
#frequency ⇒ ::Google::Cloud::Dlp::V2::DataProfileUpdateFrequency
Frequency to regenerate data profiles when the schema is modified.
-
#types ⇒ ::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence::CloudSqlSchemaModification>
The types of schema modifications to consider.
Instance Attribute Details
#frequency ⇒ ::Google::Cloud::Dlp::V2::DataProfileUpdateFrequency
Returns Frequency to regenerate data profiles when the schema is modified. Defaults to monthly.
5650 5651 5652 5653 5654 5655 5656 5657 5658 5659 5660 5661 5662 5663 5664 5665 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5650 class SchemaModifiedCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of modification that causes a profile update. module CloudSqlSchemaModification # Unused. SQL_SCHEMA_MODIFICATION_UNSPECIFIED = 0 # New columns have appeared. NEW_COLUMNS = 1 # Columns have been removed from the table. REMOVED_COLUMNS = 2 end end |
#types ⇒ ::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence::CloudSqlSchemaModification>
Returns The types of schema modifications to consider. Defaults to NEW_COLUMNS.
5650 5651 5652 5653 5654 5655 5656 5657 5658 5659 5660 5661 5662 5663 5664 5665 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5650 class SchemaModifiedCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of modification that causes a profile update. module CloudSqlSchemaModification # Unused. SQL_SCHEMA_MODIFICATION_UNSPECIFIED = 0 # New columns have appeared. NEW_COLUMNS = 1 # Columns have been removed from the table. REMOVED_COLUMNS = 2 end end |