Class: Google::Cloud::Dlp::V2::DiscoveryCloudStorageConditions
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::DiscoveryCloudStorageConditions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Requirements that must be true before a Cloud Storage bucket or object is scanned in discovery for the first time. There is an AND relationship between the top-level attributes.
Defined Under Namespace
Modules: CloudStorageBucketAttribute, CloudStorageObjectAttribute
Instance Attribute Summary collapse
-
#included_bucket_attributes ⇒ ::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudStorageConditions::CloudStorageBucketAttribute>
Required.
-
#included_object_attributes ⇒ ::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudStorageConditions::CloudStorageObjectAttribute>
Required.
Instance Attribute Details
#included_bucket_attributes ⇒ ::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudStorageConditions::CloudStorageBucketAttribute>
Returns Required. Only objects with the specified attributes will be scanned. Defaults to [ALL_SUPPORTED_BUCKETS] if unset.
5845 5846 5847 5848 5849 5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 5886 5887 5888 5889 5890 5891 5892 5893 5894 5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5845 class DiscoveryCloudStorageConditions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The attribute of an object. See # https://cloud.google.com/storage/docs/storage-classes for more information # on storage classes. module CloudStorageObjectAttribute # Unused. CLOUD_STORAGE_OBJECT_ATTRIBUTE_UNSPECIFIED = 0 # Scan objects regardless of the attribute. ALL_SUPPORTED_OBJECTS = 1 # Scan objects with the standard storage class. STANDARD = 2 # Scan objects with the nearline storage class. This will incur retrieval # fees. NEARLINE = 3 # Scan objects with the coldline storage class. This will incur retrieval # fees. COLDLINE = 4 # Scan objects with the archive storage class. This will incur retrieval # fees. ARCHIVE = 5 # Scan objects with the regional storage class. REGIONAL = 6 # Scan objects with the multi-regional storage class. MULTI_REGIONAL = 7 # Scan objects with the dual-regional storage class. This will incur # retrieval fees. DURABLE_REDUCED_AVAILABILITY = 8 end # The attribute of a bucket. module CloudStorageBucketAttribute # Unused. CLOUD_STORAGE_BUCKET_ATTRIBUTE_UNSPECIFIED = 0 # Scan buckets regardless of the attribute. ALL_SUPPORTED_BUCKETS = 1 # Buckets with [Autoclass](https://cloud.google.com/storage/docs/autoclass) # disabled. Only one of # AUTOCLASS_DISABLED or AUTOCLASS_ENABLED should be set. AUTOCLASS_DISABLED = 2 # Buckets with [Autoclass](https://cloud.google.com/storage/docs/autoclass) # enabled. Only one of # AUTOCLASS_DISABLED or AUTOCLASS_ENABLED should be set. Scanning # Autoclass-enabled buckets can affect object storage classes. AUTOCLASS_ENABLED = 3 end end |
#included_object_attributes ⇒ ::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudStorageConditions::CloudStorageObjectAttribute>
Returns Required. Only objects with the specified attributes will be scanned. If an object has one of the specified attributes but is inside an excluded bucket, it will not be scanned. Defaults to [ALL_SUPPORTED_OBJECTS]. A profile will be created even if no objects match the included_object_attributes.
5845 5846 5847 5848 5849 5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 5875 5876 5877 5878 5879 5880 5881 5882 5883 5884 5885 5886 5887 5888 5889 5890 5891 5892 5893 5894 5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5845 class DiscoveryCloudStorageConditions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The attribute of an object. See # https://cloud.google.com/storage/docs/storage-classes for more information # on storage classes. module CloudStorageObjectAttribute # Unused. CLOUD_STORAGE_OBJECT_ATTRIBUTE_UNSPECIFIED = 0 # Scan objects regardless of the attribute. ALL_SUPPORTED_OBJECTS = 1 # Scan objects with the standard storage class. STANDARD = 2 # Scan objects with the nearline storage class. This will incur retrieval # fees. NEARLINE = 3 # Scan objects with the coldline storage class. This will incur retrieval # fees. COLDLINE = 4 # Scan objects with the archive storage class. This will incur retrieval # fees. ARCHIVE = 5 # Scan objects with the regional storage class. REGIONAL = 6 # Scan objects with the multi-regional storage class. MULTI_REGIONAL = 7 # Scan objects with the dual-regional storage class. This will incur # retrieval fees. DURABLE_REDUCED_AVAILABILITY = 8 end # The attribute of a bucket. module CloudStorageBucketAttribute # Unused. CLOUD_STORAGE_BUCKET_ATTRIBUTE_UNSPECIFIED = 0 # Scan buckets regardless of the attribute. ALL_SUPPORTED_BUCKETS = 1 # Buckets with [Autoclass](https://cloud.google.com/storage/docs/autoclass) # disabled. Only one of # AUTOCLASS_DISABLED or AUTOCLASS_ENABLED should be set. AUTOCLASS_DISABLED = 2 # Buckets with [Autoclass](https://cloud.google.com/storage/docs/autoclass) # enabled. Only one of # AUTOCLASS_DISABLED or AUTOCLASS_ENABLED should be set. Scanning # Autoclass-enabled buckets can affect object storage classes. AUTOCLASS_ENABLED = 3 end end |