Class: Google::Cloud::Dlp::V2::DiscoveryConfig::OrgConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Project and scan location information. Only set when the parent is an org.

Instance Attribute Summary collapse

Instance Attribute Details

#location::Google::Cloud::Dlp::V2::DiscoveryStartingLocation

Returns The data to scan: folder, org, or project.

Returns:



5200
5201
5202
5203
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5200

class OrgConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#project_id::String

Returns The project that will run the scan. The DLP service account that exists within this project must have access to all resources that are profiled, and the DLP API must be enabled.

Returns:

  • (::String)

    The project that will run the scan. The DLP service account that exists within this project must have access to all resources that are profiled, and the DLP API must be enabled.



5200
5201
5202
5203
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5200

class OrgConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end