Class: Google::Cloud::Dlp::V2::ExcludeByImageFindings
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ExcludeByImageFindings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
The rule to exclude image findings based on spatial relationships with other image findings. For example, exclude an image finding if it overlaps with another image finding. This rule is silently ignored if the content being inspected is not an image.
Instance Attribute Summary collapse
-
#image_containment_type ⇒ ::Google::Cloud::Dlp::V2::ImageContainmentType
Specifies the required spatial relationship between the bounding boxes of the target finding and the context infoType findings.
-
#info_types ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoType>
A list of image-supported infoTypes—excluding document infoTypes—to be used as context for the exclusion rule.
Instance Attribute Details
#image_containment_type ⇒ ::Google::Cloud::Dlp::V2::ImageContainmentType
Returns Specifies the required spatial relationship between the bounding boxes of the target finding and the context infoType findings.
80 81 82 83 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 80 class ExcludeByImageFindings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#info_types ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoType>
Returns A list of image-supported infoTypes—excluding document
infoTypes—to
be used as context for the exclusion rule. A finding is excluded if
its bounding box has the specified spatial relationship (defined by
image_containment_type) with a finding of an infoType in this list.
For example, if InspectionRuleSet.info_types includes
OBJECT_TYPE/PERSON and this exclusion_rule specifies info_types as
OBJECT_TYPE/PERSON/PASSPORT with image_containment_type set to
encloses, then OBJECT_TYPE/PERSON findings will be excluded if they
are fully contained within the bounding box of an
OBJECT_TYPE/PERSON/PASSPORT finding.
80 81 82 83 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 80 class ExcludeByImageFindings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |