Class: Google::Cloud::Dlp::V2::FileStoreDataProfile

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

The profile for a file store.

  • Cloud Storage: maps 1:1 with a bucket.
  • Amazon S3: maps 1:1 with a bucket.

Defined Under Namespace

Modules: State Classes: ResourceAttributesEntry, ResourceLabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#config_snapshot::Google::Cloud::Dlp::V2::DataProfileConfigSnapshot

Returns The snapshot of the configurations used to generate the profile.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#create_time::Google::Protobuf::Timestamp

Returns The time the file store was first created.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#data_risk_level::Google::Cloud::Dlp::V2::DataRiskLevel

Returns The data risk level of this resource.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#data_source_type::Google::Cloud::Dlp::V2::DataSourceType

Returns The resource type that was profiled.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#data_storage_locations::Array<::String>

Returns For resources that have multiple storage locations, these are those regions. For Cloud Storage this is the list of regions chosen for dual-region storage. file_store_location will normally be the corresponding multi-region for the list of individual locations. The first region is always picked as the processing and storage location for the data profile.

Returns:

  • (::Array<::String>)

    For resources that have multiple storage locations, these are those regions. For Cloud Storage this is the list of regions chosen for dual-region storage. file_store_location will normally be the corresponding multi-region for the list of individual locations. The first region is always picked as the processing and storage location for the data profile.



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#domains::Array<::Google::Cloud::Dlp::V2::Domain>

Returns Domains associated with the profile.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#file_cluster_summaries::Array<::Google::Cloud::Dlp::V2::FileClusterSummary>

Returns FileClusterSummary per each cluster.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#file_store_info_type_summaries::Array<::Google::Cloud::Dlp::V2::FileStoreInfoTypeSummary>

Returns InfoTypes detected in this file store.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#file_store_is_empty::Boolean

Returns The file store does not have any files. If the profiling operation failed, this is false.

Returns:

  • (::Boolean)

    The file store does not have any files. If the profiling operation failed, this is false.



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#file_store_location::String



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#file_store_path::String

Returns The file store path.

  • Cloud Storage: gs://{bucket}
  • Amazon S3: s3://{bucket}
  • Vertex AI dataset: projects/{project_number}/locations/{location}/datasets/{dataset_id}.

Returns:

  • (::String)

    The file store path.

    • Cloud Storage: gs://{bucket}
    • Amazon S3: s3://{bucket}
    • Vertex AI dataset: projects/{project_number}/locations/{location}/datasets/{dataset_id}


7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#full_resource::String

Returns The resource name of the resource profiled. https://cloud.google.com/apis/design/resource_names#full_resource_name

Example format of an S3 bucket full resource name: //cloudasset.googleapis.com/organizations/{org_id}/otherCloudConnections/aws/arn:aws:s3:::{bucket_name}.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#last_modified_time::Google::Protobuf::Timestamp

Returns The time the file store was last modified.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#location_type::String

Returns The location type of the file store (region, dual-region, multi-region, etc). If dual-region, expect data_storage_locations to be populated.

Returns:

  • (::String)

    The location type of the file store (region, dual-region, multi-region, etc). If dual-region, expect data_storage_locations to be populated.



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#name::String

Returns The name of the profile.

Returns:

  • (::String)

    The name of the profile.



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#profile_last_generated::Google::Protobuf::Timestamp

Returns The last time the profile was generated.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#profile_status::Google::Cloud::Dlp::V2::ProfileStatus

Returns Success or error status from the most recent profile generation attempt. May be empty if the profile is still being generated.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#project_data_profile::String

Returns The resource name of the project data profile for this file store.

Returns:

  • (::String)

    The resource name of the project data profile for this file store.



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#project_id::String

Returns The Google Cloud project ID that owns the resource. For Amazon S3 buckets, this is the AWS Account Id.

Returns:

  • (::String)

    The Google Cloud project ID that owns the resource. For Amazon S3 buckets, this is the AWS Account Id.



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

Returns Resources related to this profile.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#resource_attributes::Google::Protobuf::Map{::String => ::Google::Cloud::Dlp::V2::Value}

Returns Attributes of the resource being profiled. Currently used attributes:

  • customer_managed_encryption: boolean
    • true: the resource is encrypted with a customer-managed key.
    • false: the resource is encrypted with a provider-managed key.

Returns:

  • (::Google::Protobuf::Map{::String => ::Google::Cloud::Dlp::V2::Value})

    Attributes of the resource being profiled. Currently used attributes:

    • customer_managed_encryption: boolean
      • true: the resource is encrypted with a customer-managed key.
      • false: the resource is encrypted with a provider-managed key.


7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#resource_labels::Google::Protobuf::Map{::String => ::String}

Returns The labels applied to the resource at the time the profile was generated.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    The labels applied to the resource at the time the profile was generated.



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#resource_visibility::Google::Cloud::Dlp::V2::ResourceVisibility

Returns How broadly a resource has been shared.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#sample_findings_table::Google::Cloud::Dlp::V2::BigQueryTable

Returns The BigQuery table to which the sample findings are written.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#sensitivity_score::Google::Cloud::Dlp::V2::SensitivityScore

Returns The sensitivity score of this resource.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#state::Google::Cloud::Dlp::V2::FileStoreDataProfile::State

Returns State of a profile.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#tags::Array<::Google::Cloud::Dlp::V2::Tag>

Returns The tags attached to the resource, including any tags attached during profiling.

Returns:



7898
7899
7900
7901
7902
7903
7904
7905
7906
7907
7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7898

class FileStoreDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::Dlp::V2::Value]
  class ResourceAttributesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end