Class: Google::Cloud::Dlp::V2::ImageContainmentType

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Specifies the relationship between bounding boxes for image findings.

Instance Attribute Summary collapse

Instance Attribute Details

#encloses::Google::Cloud::Dlp::V2::Encloses

Returns The context finding's bounding box must fully contain the target finding's bounding box.

Note: The following fields are mutually exclusive: encloses, fully_inside, overlaps. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::Encloses)

    The context finding's bounding box must fully contain the target finding's bounding box.

    Note: The following fields are mutually exclusive: encloses, fully_inside, overlaps. If a field in that set is populated, all other fields in the set will automatically be cleared.



7083
7084
7085
7086
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7083

class ImageContainmentType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fully_inside::Google::Cloud::Dlp::V2::FullyInside

Returns The context finding's bounding box must be fully inside the target finding's bounding box.

Note: The following fields are mutually exclusive: fully_inside, encloses, overlaps. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::FullyInside)

    The context finding's bounding box must be fully inside the target finding's bounding box.

    Note: The following fields are mutually exclusive: fully_inside, encloses, overlaps. If a field in that set is populated, all other fields in the set will automatically be cleared.



7083
7084
7085
7086
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7083

class ImageContainmentType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#overlaps::Google::Cloud::Dlp::V2::Overlap

Returns The context finding's bounding box and the target finding's bounding box must have a non-zero intersection.

Note: The following fields are mutually exclusive: overlaps, encloses, fully_inside. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::Overlap)

    The context finding's bounding box and the target finding's bounding box must have a non-zero intersection.

    Note: The following fields are mutually exclusive: overlaps, encloses, fully_inside. If a field in that set is populated, all other fields in the set will automatically be cleared.



7083
7084
7085
7086
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7083

class ImageContainmentType
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end