Class: Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Configuration for determining how redaction of images should occur.
Defined Under Namespace
Classes: AllInfoTypes, AllText, SelectedInfoTypes
Instance Attribute Summary collapse
-
#all_info_types ⇒ ::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::AllInfoTypes
Apply transformation to all findings not specified in other ImageTransformation's selected_info_types.
-
#all_text ⇒ ::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::AllText
Apply transformation to all text that doesn't match an infoType.
-
#redaction_color ⇒ ::Google::Cloud::Dlp::V2::Color
The color to use when redacting content from an image.
-
#selected_info_types ⇒ ::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::SelectedInfoTypes
Apply transformation to the selected info_types.
Instance Attribute Details
#all_info_types ⇒ ::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::AllInfoTypes
Returns Apply transformation to all findings not specified in other ImageTransformation's selected_info_types. Only one instance is allowed within the ImageTransformations message.
Note: The following fields are mutually exclusive: all_info_types, selected_info_types, all_text. If a field in that set is populated, all other fields in the set will automatically be cleared.
2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2696 class ImageTransformation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Apply transformation to the selected info_types. # @!attribute [rw] info_types # @return [::Array<::Google::Cloud::Dlp::V2::InfoType>] # Required. InfoTypes to apply the transformation to. Required. Provided # InfoType must be unique within the ImageTransformations message. class SelectedInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply transformation to all findings. class AllInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply to all text. class AllText include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#all_text ⇒ ::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::AllText
Returns Apply transformation to all text that doesn't match an infoType. Only one instance is allowed within the ImageTransformations message.
Note: The following fields are mutually exclusive: all_text, selected_info_types, all_info_types. If a field in that set is populated, all other fields in the set will automatically be cleared.
2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2696 class ImageTransformation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Apply transformation to the selected info_types. # @!attribute [rw] info_types # @return [::Array<::Google::Cloud::Dlp::V2::InfoType>] # Required. InfoTypes to apply the transformation to. Required. Provided # InfoType must be unique within the ImageTransformations message. class SelectedInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply transformation to all findings. class AllInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply to all text. class AllText include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#redaction_color ⇒ ::Google::Cloud::Dlp::V2::Color
Returns The color to use when redacting content from an image. If not specified, the default is black.
2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2696 class ImageTransformation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Apply transformation to the selected info_types. # @!attribute [rw] info_types # @return [::Array<::Google::Cloud::Dlp::V2::InfoType>] # Required. InfoTypes to apply the transformation to. Required. Provided # InfoType must be unique within the ImageTransformations message. class SelectedInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply transformation to all findings. class AllInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply to all text. class AllText include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#selected_info_types ⇒ ::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::SelectedInfoTypes
Returns Apply transformation to the selected info_types.
Note: The following fields are mutually exclusive: selected_info_types, all_info_types, all_text. If a field in that set is populated, all other fields in the set will automatically be cleared.
2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2696 class ImageTransformation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Apply transformation to the selected info_types. # @!attribute [rw] info_types # @return [::Array<::Google::Cloud::Dlp::V2::InfoType>] # Required. InfoTypes to apply the transformation to. Required. Provided # InfoType must be unique within the ImageTransformations message. class SelectedInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply transformation to all findings. class AllInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply to all text. class AllText include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |