Class: Google::Cloud::Dlp::V2::InspectConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used.

Defined Under Namespace

Classes: FindingLimits, InfoTypeLikelihood

Instance Attribute Summary collapse

Instance Attribute Details

#content_options::Array<::Google::Cloud::Dlp::V2::ContentOption>

Returns Deprecated and unused.

Returns:



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#custom_info_types::Array<::Google::Cloud::Dlp::V2::CustomInfoType>

Returns CustomInfoTypes provided by the user. See https://cloud.google.com/sensitive-data-protection/docs/creating-custom-infotypes to learn more.

Returns:



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#exclude_info_types::Boolean

Returns When true, excludes type information of the findings. This is not used for data profiling.

Returns:

  • (::Boolean)

    When true, excludes type information of the findings. This is not used for data profiling.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#include_quote::Boolean

Returns When true, a contextual quote from the data that triggered a finding is included in the response; see Finding.quote. This is not used for data profiling.

Returns:

  • (::Boolean)

    When true, a contextual quote from the data that triggered a finding is included in the response; see Finding.quote. This is not used for data profiling.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#info_types::Array<::Google::Cloud::Dlp::V2::InfoType>

Returns Restricts what info_types to look for. The values must correspond to InfoType values returned by ListInfoTypes or listed at https://cloud.google.com/sensitive-data-protection/docs/infotypes-reference.

When no InfoTypes or CustomInfoTypes are specified in a request, the system may automatically choose a default list of detectors to run, which may change over time.

If you need precise control and predictability as to what detectors are run you should specify specific InfoTypes listed in the reference, otherwise a default list will be used, which may change over time.

Returns:

  • (::Array<::Google::Cloud::Dlp::V2::InfoType>)

    Restricts what info_types to look for. The values must correspond to InfoType values returned by ListInfoTypes or listed at https://cloud.google.com/sensitive-data-protection/docs/infotypes-reference.

    When no InfoTypes or CustomInfoTypes are specified in a request, the system may automatically choose a default list of detectors to run, which may change over time.

    If you need precise control and predictability as to what detectors are run you should specify specific InfoTypes listed in the reference, otherwise a default list will be used, which may change over time.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#limits::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits

Returns Configuration to control the number of findings returned. This is not used for data profiling.

When redacting sensitive data from images, finding limits don't apply. They can cause unexpected or inconsistent results, where only some data is redacted. Don't include finding limits in RedactImage requests. Otherwise, Cloud DLP returns an error.

When set within an InspectJobConfig, the specified maximum values aren't hard limits. If an inspection job reaches these limits, the job ends gradually, not abruptly. Therefore, the actual number of findings that Cloud DLP returns can be multiple times higher than these maximum values.

Returns:

  • (::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits)

    Configuration to control the number of findings returned. This is not used for data profiling.

    When redacting sensitive data from images, finding limits don't apply. They can cause unexpected or inconsistent results, where only some data is redacted. Don't include finding limits in RedactImage requests. Otherwise, Cloud DLP returns an error.

    When set within an InspectJobConfig, the specified maximum values aren't hard limits. If an inspection job reaches these limits, the job ends gradually, not abruptly. Therefore, the actual number of findings that Cloud DLP returns can be multiple times higher than these maximum values.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#min_likelihood::Google::Cloud::Dlp::V2::Likelihood

Returns Only returns findings equal to or above this threshold. The default is POSSIBLE.

In general, the highest likelihood setting yields the fewest findings in results and the lowest chance of a false positive. For more information, see Match likelihood.

Returns:

  • (::Google::Cloud::Dlp::V2::Likelihood)

    Only returns findings equal to or above this threshold. The default is POSSIBLE.

    In general, the highest likelihood setting yields the fewest findings in results and the lowest chance of a false positive. For more information, see Match likelihood.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#min_likelihood_per_info_type::Array<::Google::Cloud::Dlp::V2::InspectConfig::InfoTypeLikelihood>

Returns Minimum likelihood per infotype. For each infotype, a user can specify a minimum likelihood. The system only returns a finding if its likelihood is above this threshold. If this field is not set, the system uses the InspectConfig min_likelihood.

Returns:

  • (::Array<::Google::Cloud::Dlp::V2::InspectConfig::InfoTypeLikelihood>)

    Minimum likelihood per infotype. For each infotype, a user can specify a minimum likelihood. The system only returns a finding if its likelihood is above this threshold. If this field is not set, the system uses the InspectConfig min_likelihood.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#rule_set::Array<::Google::Cloud::Dlp::V2::InspectionRuleSet>

Returns Set of rules to apply to the findings for this InspectConfig. Exclusion rules, contained in the set are executed in the end, other rules are executed in the order they are specified for each info type. Not supported for the metadata_key_value_expression CustomInfoType.

Returns:

  • (::Array<::Google::Cloud::Dlp::V2::InspectionRuleSet>)

    Set of rules to apply to the findings for this InspectConfig. Exclusion rules, contained in the set are executed in the end, other rules are executed in the order they are specified for each info type. Not supported for the metadata_key_value_expression CustomInfoType.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 318

class InspectConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Configuration for setting a minimum likelihood per infotype. Used to
  # customize the minimum likelihood level for specific infotypes in the
  # request. For example, use this if you want to lower the precision for
  # PERSON_NAME without lowering the precision for the other infotypes in the
  # request.
  # @!attribute [rw] info_type
  #   @return [::Google::Cloud::Dlp::V2::InfoType]
  #     Type of information the likelihood threshold applies to. Only one
  #     likelihood per info_type should be provided. If InfoTypeLikelihood does
  #     not have an info_type, the configuration fails.
  # @!attribute [rw] min_likelihood
  #   @return [::Google::Cloud::Dlp::V2::Likelihood]
  #     Only returns findings equal to or above this threshold. This field is
  #     required or else the configuration fails.
  class InfoTypeLikelihood
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Configuration to control the number of findings returned for inspection.
  # This is not used for de-identification or data profiling.
  #
  # When redacting sensitive data from images, finding limits don't apply. They
  # can cause unexpected or inconsistent results, where only some data is
  # redacted. Don't include finding limits in
  # {::Google::Cloud::Dlp::V2::DlpService::Client#redact_image RedactImage}
  # requests. Otherwise, Cloud DLP returns an error.
  # @!attribute [rw] max_findings_per_item
  #   @return [::Integer]
  #     Max number of findings that are returned for each item scanned.
  #
  #     When set within an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest},
  #     this field is ignored.
  #
  #     This value isn't a hard limit. If the number of findings for an item
  #     reaches this limit, the inspection of that item ends gradually, not
  #     abruptly. Therefore, the actual number of findings that Cloud DLP returns
  #     for the item can be multiple times higher than this value.
  # @!attribute [rw] max_findings_per_request
  #   @return [::Integer]
  #     Max number of findings that are returned per request or job.
  #
  #     If you set this field in an
  #     {::Google::Cloud::Dlp::V2::InspectContentRequest InspectContentRequest}, the
  #     resulting maximum value is the value that you set or 3,000, whichever is
  #     lower.
  #
  #     This value isn't a hard limit. If an inspection reaches this limit, the
  #     inspection ends gradually, not abruptly. Therefore, the actual number of
  #     findings that Cloud DLP returns can be multiple times higher than this
  #     value.
  # @!attribute [rw] max_findings_per_info_type
  #   @return [::Array<::Google::Cloud::Dlp::V2::InspectConfig::FindingLimits::InfoTypeLimit>]
  #     Configuration of findings limit given for specified infoTypes.
  class FindingLimits
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Max findings configuration per infoType, per content item or long
    # running DlpJob.
    # @!attribute [rw] info_type
    #   @return [::Google::Cloud::Dlp::V2::InfoType]
    #     Type of information the findings limit applies to. Only one limit per
    #     info_type should be provided. If InfoTypeLimit does not have an
    #     info_type, the DLP API applies the limit against all info_types that
    #     are found but not specified in another InfoTypeLimit.
    # @!attribute [rw] max_findings
    #   @return [::Integer]
    #     Max findings limit for the given infoType.
    class InfoTypeLimit
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end