Class: Google::Cloud::Dlp::V2::JobTrigger
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::JobTrigger
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Contains a configuration to make API calls on a repeating basis. See https://cloud.google.com/sensitive-data-protection/docs/concepts-job-triggers to learn more.
Defined Under Namespace
Modules: Status Classes: Trigger
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#description ⇒ ::String
User provided description (max 256 chars).
-
#display_name ⇒ ::String
Display name (max 100 chars).
-
#errors ⇒ ::Array<::Google::Cloud::Dlp::V2::Error>
readonly
Output only.
-
#inspect_job ⇒ ::Google::Cloud::Dlp::V2::InspectJobConfig
For inspect jobs, a snapshot of the configuration.
-
#last_run_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Unique resource name for the triggeredJob, assigned by the service when the triggeredJob is created, for example
projects/dlp-test-project/jobTriggers/53234423. -
#status ⇒ ::Google::Cloud::Dlp::V2::JobTrigger::Status
Required.
-
#triggers ⇒ ::Array<::Google::Cloud::Dlp::V2::JobTrigger::Trigger>
A list of triggers which will be OR'ed together.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The creation timestamp of a triggeredJob.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#description ⇒ ::String
Returns User provided description (max 256 chars).
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#display_name ⇒ ::String
Returns Display name (max 100 chars).
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#errors ⇒ ::Array<::Google::Cloud::Dlp::V2::Error> (readonly)
Returns Output only. A stream of errors encountered when the trigger was activated. Repeated errors may result in the JobTrigger automatically being paused. Will return the last 100 errors. Whenever the JobTrigger is modified this list will be cleared.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#inspect_job ⇒ ::Google::Cloud::Dlp::V2::InspectJobConfig
Returns For inspect jobs, a snapshot of the configuration.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#last_run_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of the last time this trigger executed.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#name ⇒ ::String
Returns Unique resource name for the triggeredJob, assigned by the service when the
triggeredJob is created, for example
projects/dlp-test-project/jobTriggers/53234423.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#status ⇒ ::Google::Cloud::Dlp::V2::JobTrigger::Status
Returns Required. A status for this trigger.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#triggers ⇒ ::Array<::Google::Cloud::Dlp::V2::JobTrigger::Trigger>
Returns A list of triggers which will be OR'ed together. Only one in the list needs to trigger for a job to be started. The list may contain only a single Schedule trigger and must have at least one object.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last update timestamp of a triggeredJob.
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 3913 3914 3915 3916 3917 3918 3919 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3882 class JobTrigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # What event needs to occur for a new job to be started. # @!attribute [rw] schedule # @return [::Google::Cloud::Dlp::V2::Schedule] # Create a job on a repeating basis based on the elapse of time. # # Note: The following fields are mutually exclusive: `schedule`, `manual`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] manual # @return [::Google::Cloud::Dlp::V2::Manual] # For use with hybrid jobs. Jobs must be manually created and finished. # # Note: The following fields are mutually exclusive: `manual`, `schedule`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Trigger include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Whether the trigger is currently active. If PAUSED or CANCELLED, no jobs # will be created with this configuration. The service may automatically # pause triggers experiencing frequent errors. To restart a job, set the # status to HEALTHY after correcting user errors. module Status # Unused. STATUS_UNSPECIFIED = 0 # Trigger is healthy. HEALTHY = 1 # Trigger is temporarily paused. PAUSED = 2 # Trigger is cancelled and can not be resumed. CANCELLED = 3 end end |