Class: Google::Cloud::Dlp::V2::KeyValueMetadataLabel

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

The metadata key that contains a finding.

Instance Attribute Summary collapse

Instance Attribute Details

#key::String

Returns The metadata key. The format depends on the source of the metadata.

Example:

  • MSIP_Label_122709e3-8f6b-4860-985f-7f722a94f61e_Enabled (a Microsoft Purview Information Protection key example).

Returns:

  • (::String)

    The metadata key. The format depends on the source of the metadata.

    Example:

    • MSIP_Label_122709e3-8f6b-4860-985f-7f722a94f61e_Enabled (a Microsoft Purview Information Protection key example)


869
870
871
872
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 869

class KeyValueMetadataLabel
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end