Class: Google::Cloud::Dlp::V2::ListTableDataProfilesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ListTableDataProfilesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Request to list the profiles generated for a given organization or project.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Allows filtering.
-
#order_by ⇒ ::String
Comma-separated list of fields to order by, followed by
ascordescpostfix. -
#page_size ⇒ ::Integer
Size of the page.
-
#page_token ⇒ ::String
Page token to continue retrieval.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
7108 7109 7110 7111 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7108 class ListTableDataProfilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
7108 7109 7110 7111 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7108 class ListTableDataProfilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
7108 7109 7110 7111 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7108 class ListTableDataProfilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
7108 7109 7110 7111 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7108 class ListTableDataProfilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
7108 7109 7110 7111 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7108 class ListTableDataProfilesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |