Class: Google::Cloud::Dlp::V2::LocationSupport
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::LocationSupport
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Locations at which a feature can be used.
Defined Under Namespace
Modules: RegionalizationScope
Instance Attribute Summary collapse
-
#locations ⇒ ::Array<::String>
Specific locations where the feature may be used.
-
#regionalization_scope ⇒ ::Google::Cloud::Dlp::V2::LocationSupport::RegionalizationScope
The current scope for location on this feature.
Instance Attribute Details
#locations ⇒ ::Array<::String>
Returns Specific locations where the feature may be used. Examples: us-central1, us, asia, global If scope is ANY_LOCATION, no regions will be listed.
1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1553 class LocationSupport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope for a feature. module RegionalizationScope # Invalid. REGIONALIZATION_SCOPE_UNSPECIFIED = 0 # Feature may be used with one or more regions. See locations for details. REGIONAL = 1 # Feature may be used anywhere. Default value. ANY_LOCATION = 2 end end |
#regionalization_scope ⇒ ::Google::Cloud::Dlp::V2::LocationSupport::RegionalizationScope
Returns The current scope for location on this feature. This may expand over time.
1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1553 class LocationSupport include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The location scope for a feature. module RegionalizationScope # Invalid. REGIONALIZATION_SCOPE_UNSPECIFIED = 0 # Feature may be used with one or more regions. See locations for details. REGIONAL = 1 # Feature may be used anywhere. Default value. ANY_LOCATION = 2 end end |