Class: Google::Cloud::Dlp::V2::MetadataLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Metadata Location

Instance Attribute Summary collapse

Instance Attribute Details

#key_value_metadata_label::Google::Cloud::Dlp::V2::KeyValueMetadataLabel

Returns Metadata key that contains the finding.

Note: The following fields are mutually exclusive: key_value_metadata_label, storage_label. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::KeyValueMetadataLabel)

    Metadata key that contains the finding.

    Note: The following fields are mutually exclusive: key_value_metadata_label, storage_label. If a field in that set is populated, all other fields in the set will automatically be cleared.



846
847
848
849
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 846

class MetadataLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#storage_label::Google::Cloud::Dlp::V2::StorageMetadataLabel

Returns Storage metadata.

Note: The following fields are mutually exclusive: storage_label, key_value_metadata_label. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::StorageMetadataLabel)

    Storage metadata.

    Note: The following fields are mutually exclusive: storage_label, key_value_metadata_label. If a field in that set is populated, all other fields in the set will automatically be cleared.



846
847
848
849
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 846

class MetadataLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::Google::Cloud::Dlp::V2::MetadataType

Returns Type of metadata containing the finding.

Returns:



846
847
848
849
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 846

class MetadataLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end