Class: Google::Cloud::Dlp::V2::OtherCloudDiscoveryStartingLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

The other cloud starting location for discovery.

Defined Under Namespace

Classes: AwsDiscoveryStartingLocation

Instance Attribute Summary collapse

Instance Attribute Details

#aws_location::Google::Cloud::Dlp::V2::OtherCloudDiscoveryStartingLocation::AwsDiscoveryStartingLocation

Returns The AWS starting location for discovery.



6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
6194
6195
6196
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6173

class OtherCloudDiscoveryStartingLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The AWS starting location for discovery.
  # @!attribute [rw] account_id
  #   @return [::String]
  #     The AWS account ID that this discovery config applies to.
  #     Within an AWS organization, you can find the AWS account ID inside an
  #     AWS account ARN. Example:
  #     arn:\\{partition}:organizations::\\{management_account_id}:account/\\{org_id}/\\{account_id}
  #
  #     Note: The following fields are mutually exclusive: `account_id`, `all_asset_inventory_assets`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] all_asset_inventory_assets
  #   @return [::Boolean]
  #     All AWS assets stored in Asset Inventory that didn't match other AWS
  #     discovery configs.
  #
  #     Note: The following fields are mutually exclusive: `all_asset_inventory_assets`, `account_id`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class AwsDiscoveryStartingLocation
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end