Class: Google::Cloud::Dlp::V2::OutputStorageConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Cloud repository for storing output.

Defined Under Namespace

Modules: OutputSchema

Instance Attribute Summary collapse

Instance Attribute Details

#output_schema::Google::Cloud::Dlp::V2::OutputStorageConfig::OutputSchema

Returns Schema used for writing the findings for Inspect jobs. This field is only used for Inspect and must be unspecified for Risk jobs. Columns are derived from the Finding object. If appending to an existing table, any columns from the predefined schema that are missing will be added. No columns in the existing table will be deleted.

If unspecified, then all available columns will be used for a new table or an (existing) table with no schema, and no changes will be made to an existing table that has a schema. Only for use with external storage.

Returns:

  • (::Google::Cloud::Dlp::V2::OutputStorageConfig::OutputSchema)

    Schema used for writing the findings for Inspect jobs. This field is only used for Inspect and must be unspecified for Risk jobs. Columns are derived from the Finding object. If appending to an existing table, any columns from the predefined schema that are missing will be added. No columns in the existing table will be deleted.

    If unspecified, then all available columns will be used for a new table or an (existing) table with no schema, and no changes will be made to an existing table that has a schema. Only for use with external storage.



1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1212

class OutputStorageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Predefined schemas for storing findings.
  # Only for use with external storage.
  module OutputSchema
    # Unused.
    OUTPUT_SCHEMA_UNSPECIFIED = 0

    # Basic schema including only `info_type`, `quote`, `certainty`, and
    # `timestamp`.
    BASIC_COLUMNS = 1

    # Schema tailored to findings from scanning Cloud Storage.
    GCS_COLUMNS = 2

    # Schema tailored to findings from scanning Google Datastore.
    DATASTORE_COLUMNS = 3

    # Schema tailored to findings from scanning Google BigQuery.
    BIG_QUERY_COLUMNS = 4

    # Schema containing all columns.
    ALL_COLUMNS = 5
  end
end

#storage_path::Google::Cloud::Dlp::V2::CloudStoragePath

Returns Store findings in an existing Cloud Storage bucket. Files will be generated with the job ID and file part number as the filename and will contain findings in textproto format as SaveToGcsFindingsOutput. The filename will follow the naming convention <job_id>-<shard_number>. Example: my-job-id-2.

Supported for Inspect jobs. The bucket must not be the same as the bucket being inspected. If storing findings to Cloud Storage, the output schema field should not be set. If set, it will be ignored.

Note: The following fields are mutually exclusive: storage_path, table. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::CloudStoragePath)

    Store findings in an existing Cloud Storage bucket. Files will be generated with the job ID and file part number as the filename and will contain findings in textproto format as SaveToGcsFindingsOutput. The filename will follow the naming convention <job_id>-<shard_number>. Example: my-job-id-2.

    Supported for Inspect jobs. The bucket must not be the same as the bucket being inspected. If storing findings to Cloud Storage, the output schema field should not be set. If set, it will be ignored.

    Note: The following fields are mutually exclusive: storage_path, table. If a field in that set is populated, all other fields in the set will automatically be cleared.



1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1212

class OutputStorageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Predefined schemas for storing findings.
  # Only for use with external storage.
  module OutputSchema
    # Unused.
    OUTPUT_SCHEMA_UNSPECIFIED = 0

    # Basic schema including only `info_type`, `quote`, `certainty`, and
    # `timestamp`.
    BASIC_COLUMNS = 1

    # Schema tailored to findings from scanning Cloud Storage.
    GCS_COLUMNS = 2

    # Schema tailored to findings from scanning Google Datastore.
    DATASTORE_COLUMNS = 3

    # Schema tailored to findings from scanning Google BigQuery.
    BIG_QUERY_COLUMNS = 4

    # Schema containing all columns.
    ALL_COLUMNS = 5
  end
end

#table::Google::Cloud::Dlp::V2::BigQueryTable

Returns Store findings in an existing table or a new table in an existing dataset. If table_id is not set a new one will be generated for you with the following format: dlp_googleapis_yyyy_mm_dd_[dlp_job_id]. Pacific time zone will be used for generating the date details.

For Inspect, each column in an existing output table must have the same name, type, and mode of a field in the Finding object.

For Risk, an existing output table should be the output of a previous Risk analysis job run on the same source table, with the same privacy metric and quasi-identifiers. Risk jobs that analyze the same table but compute a different privacy metric, or use different sets of quasi-identifiers, cannot store their results in the same table.

Note: The following fields are mutually exclusive: table, storage_path. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dlp::V2::BigQueryTable)

    Store findings in an existing table or a new table in an existing dataset. If table_id is not set a new one will be generated for you with the following format: dlp_googleapis_yyyy_mm_dd_[dlp_job_id]. Pacific time zone will be used for generating the date details.

    For Inspect, each column in an existing output table must have the same name, type, and mode of a field in the Finding object.

    For Risk, an existing output table should be the output of a previous Risk analysis job run on the same source table, with the same privacy metric and quasi-identifiers. Risk jobs that analyze the same table but compute a different privacy metric, or use different sets of quasi-identifiers, cannot store their results in the same table.

    Note: The following fields are mutually exclusive: table, storage_path. If a field in that set is populated, all other fields in the set will automatically be cleared.



1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1212

class OutputStorageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Predefined schemas for storing findings.
  # Only for use with external storage.
  module OutputSchema
    # Unused.
    OUTPUT_SCHEMA_UNSPECIFIED = 0

    # Basic schema including only `info_type`, `quote`, `certainty`, and
    # `timestamp`.
    BASIC_COLUMNS = 1

    # Schema tailored to findings from scanning Cloud Storage.
    GCS_COLUMNS = 2

    # Schema tailored to findings from scanning Google Datastore.
    DATASTORE_COLUMNS = 3

    # Schema tailored to findings from scanning Google BigQuery.
    BIG_QUERY_COLUMNS = 4

    # Schema containing all columns.
    ALL_COLUMNS = 5
  end
end