Class: Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::AuxiliaryTable

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

An auxiliary table contains statistical information on the relative frequency of different quasi-identifiers values. It has one or several quasi-identifiers columns, and one column that indicates the relative frequency of each quasi-identifier tuple. If a tuple is present in the data but not in the auxiliary table, the corresponding relative frequency is assumed to be zero (and thus, the tuple is highly reidentifiable).

Defined Under Namespace

Classes: QuasiIdField

Instance Attribute Summary collapse

Instance Attribute Details

#quasi_ids::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::AuxiliaryTable::QuasiIdField>

Returns Required. Quasi-identifier columns.

Returns:



2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2169

class AuxiliaryTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A quasi-identifier column has a custom_tag, used to know which column
  # in the data corresponds to which column in the statistical model.
  # @!attribute [rw] field
  #   @return [::Google::Cloud::Dlp::V2::FieldId]
  #     Identifies the column.
  # @!attribute [rw] custom_tag
  #   @return [::String]
  #     A auxiliary field.
  class QuasiIdField
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#relative_frequency::Google::Cloud::Dlp::V2::FieldId

Returns Required. The relative frequency column must contain a floating-point number between 0 and 1 (inclusive). Null values are assumed to be zero.

Returns:

  • (::Google::Cloud::Dlp::V2::FieldId)

    Required. The relative frequency column must contain a floating-point number between 0 and 1 (inclusive). Null values are assumed to be zero.



2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2169

class AuxiliaryTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A quasi-identifier column has a custom_tag, used to know which column
  # in the data corresponds to which column in the statistical model.
  # @!attribute [rw] field
  #   @return [::Google::Cloud::Dlp::V2::FieldId]
  #     Identifies the column.
  # @!attribute [rw] custom_tag
  #   @return [::String]
  #     A auxiliary field.
  class QuasiIdField
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#table::Google::Cloud::Dlp::V2::BigQueryTable

Returns Required. Auxiliary table location.

Returns:



2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2169

class AuxiliaryTable
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A quasi-identifier column has a custom_tag, used to know which column
  # in the data corresponds to which column in the statistical model.
  # @!attribute [rw] field
  #   @return [::Google::Cloud::Dlp::V2::FieldId]
  #     Identifies the column.
  # @!attribute [rw] custom_tag
  #   @return [::String]
  #     A auxiliary field.
  class QuasiIdField
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end