Class: Google::Cloud::Dlp::V2::ProcessingLocation::DocumentFallbackLocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

Configure document processing to fall back to any of the following processing options if document processing is unavailable in the original request location.

Instance Attribute Summary collapse

Instance Attribute Details

#global_processing::Google::Cloud::Dlp::V2::ProcessingLocation::GlobalProcessing

Returns Processing occurs in the global region.

Returns:



8484
8485
8486
8487
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8484

class DocumentFallbackLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#multi_region_processing::Google::Cloud::Dlp::V2::ProcessingLocation::MultiRegionProcessing

Returns Processing occurs in a multi-region that contains the current region if available.

Returns:



8484
8485
8486
8487
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8484

class DocumentFallbackLocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end