Class: Google::Cloud::Dlp::V2::RecordCondition::Expressions
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::RecordCondition::Expressions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
An expression, consisting of an operator and conditions.
Defined Under Namespace
Modules: LogicalOperator
Instance Attribute Summary collapse
-
#conditions ⇒ ::Google::Cloud::Dlp::V2::RecordCondition::Conditions
Conditions to apply to the expression.
-
#logical_operator ⇒ ::Google::Cloud::Dlp::V2::RecordCondition::Expressions::LogicalOperator
The operator to apply to the result of conditions.
Instance Attribute Details
#conditions ⇒ ::Google::Cloud::Dlp::V2::RecordCondition::Conditions
Returns Conditions to apply to the expression.
3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3506 class Expressions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Logical operators for conditional checks. module LogicalOperator # Unused LOGICAL_OPERATOR_UNSPECIFIED = 0 # Conditional AND AND = 1 end end |
#logical_operator ⇒ ::Google::Cloud::Dlp::V2::RecordCondition::Expressions::LogicalOperator
Returns The operator to apply to the result of conditions. Default and currently
only supported value is AND.
3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3506 class Expressions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Logical operators for conditional checks. module LogicalOperator # Unused LOGICAL_OPERATOR_UNSPECIFIED = 0 # Conditional AND AND = 1 end end |