Class: Google::Cloud::Dlp::V2::RedactImageRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::RedactImageRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Request to search for potentially sensitive info in an image and redact it by covering it with a colored rectangle.
Defined Under Namespace
Classes: ImageRedactionConfig
Instance Attribute Summary collapse
-
#byte_item ⇒ ::Google::Cloud::Dlp::V2::ByteContentItem
The content must be PNG, JPEG, SVG or BMP.
-
#deidentify_template ⇒ ::String
The full resource name of the de-identification template to use.
-
#image_redaction_configs ⇒ ::Array<::Google::Cloud::Dlp::V2::RedactImageRequest::ImageRedactionConfig>
The configuration for specifying what content to redact from images.
-
#include_findings ⇒ ::Boolean
Whether the response should include findings along with the redacted image.
-
#inspect_config ⇒ ::Google::Cloud::Dlp::V2::InspectConfig
Configuration for the inspector.
-
#inspect_template ⇒ ::String
The full resource name of the inspection template to use.
-
#location_id ⇒ ::String
Deprecated.
-
#parent ⇒ ::String
Parent resource name.
Instance Attribute Details
#byte_item ⇒ ::Google::Cloud::Dlp::V2::ByteContentItem
Returns The content must be PNG, JPEG, SVG or BMP.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#deidentify_template ⇒ ::String
Returns The full resource name of the de-identification template to use. Settings
in the main image_redaction_configs field override the corresponding
settings in this de-identification template. The request fails if the
type of the template's deidentify_config is not image_transformations.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#image_redaction_configs ⇒ ::Array<::Google::Cloud::Dlp::V2::RedactImageRequest::ImageRedactionConfig>
Returns The configuration for specifying what content to redact from images.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#include_findings ⇒ ::Boolean
Returns Whether the response should include findings along with the redacted image.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#inspect_config ⇒ ::Google::Cloud::Dlp::V2::InspectConfig
Returns Configuration for the inspector.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#inspect_template ⇒ ::String
Returns The full resource name of the inspection template to use. Settings in the
main inspect_config field override the corresponding settings in this
inspection template.
The merge behavior is as follows:
- Singular field: The main field's value replaces the value of the corresponding field in the template.
- Repeated fields: The field values are appended to the list defined in the template.
- Sub-messages and groups: The fields are recursively merged.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#location_id ⇒ ::String
Returns Deprecated. This field has no effect.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#parent ⇒ ::String
Returns Parent resource name.
The format of this value varies depending on whether you have specified a processing location:
- Projects scope, location specified:
projects/{project_id}/locations/{location_id} - Projects scope, no location specified (defaults to global):
projects/{project_id}
The following example parent string specifies a parent project with the
identifier example-project, and specifies the europe-west3 location
for processing data:
parent=projects/example-project/locations/europe-west3.
1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1055 class RedactImageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # Only one per info_type should be provided per request. If not # specified, and redact_all_text is false, the DLP API will redact all # text that it matches against all info_types that are found, but not # specified in another ImageRedactionConfig. # # Note: The following fields are mutually exclusive: `info_type`, `redact_all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redact_all_text # @return [::Boolean] # If true, all text found in the image, regardless whether it matches an # info_type, is redacted. Only one should be provided. # # Note: The following fields are mutually exclusive: `redact_all_text`, `info_type`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not specified, # the default is black. class ImageRedactionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |