Class: Google::Cloud::Dlp::V2::StatisticalTable
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::StatisticalTable
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
An auxiliary table containing statistical information on the relative frequency of different quasi-identifiers values. It has one or several quasi-identifiers columns, and one column that indicates the relative frequency of each quasi-identifier tuple. If a tuple is present in the data but not in the auxiliary table, the corresponding relative frequency is assumed to be zero (and thus, the tuple is highly reidentifiable).
Defined Under Namespace
Classes: QuasiIdentifierField
Instance Attribute Summary collapse
-
#quasi_ids ⇒ ::Array<::Google::Cloud::Dlp::V2::StatisticalTable::QuasiIdentifierField>
Required.
-
#relative_frequency ⇒ ::Google::Cloud::Dlp::V2::FieldId
Required.
-
#table ⇒ ::Google::Cloud::Dlp::V2::BigQueryTable
Required.
Instance Attribute Details
#quasi_ids ⇒ ::Array<::Google::Cloud::Dlp::V2::StatisticalTable::QuasiIdentifierField>
Returns Required. Quasi-identifier columns.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1979 class StatisticalTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A quasi-identifier column has a custom_tag, used to know which column # in the data corresponds to which column in the statistical model. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Identifies the column. # @!attribute [rw] custom_tag # @return [::String] # A column can be tagged with a custom tag. In this case, the user must # indicate an auxiliary table that contains statistical information on # the possible values of this column. class QuasiIdentifierField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#relative_frequency ⇒ ::Google::Cloud::Dlp::V2::FieldId
Returns Required. The relative frequency column must contain a floating-point number between 0 and 1 (inclusive). Null values are assumed to be zero.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1979 class StatisticalTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A quasi-identifier column has a custom_tag, used to know which column # in the data corresponds to which column in the statistical model. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Identifies the column. # @!attribute [rw] custom_tag # @return [::String] # A column can be tagged with a custom tag. In this case, the user must # indicate an auxiliary table that contains statistical information on # the possible values of this column. class QuasiIdentifierField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#table ⇒ ::Google::Cloud::Dlp::V2::BigQueryTable
Returns Required. Auxiliary table location.
1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1979 class StatisticalTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A quasi-identifier column has a custom_tag, used to know which column # in the data corresponds to which column in the statistical model. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Identifies the column. # @!attribute [rw] custom_tag # @return [::String] # A column can be tagged with a custom tag. In this case, the user must # indicate an auxiliary table that contains statistical information on # the possible values of this column. class QuasiIdentifierField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |