Class: Google::Cloud::Dlp::V2::TableDataProfile

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

The profile for a scanned table.

Defined Under Namespace

Modules: State Classes: ResourceLabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#config_snapshot::Google::Cloud::Dlp::V2::DataProfileConfigSnapshot

Returns The snapshot of the configurations used to generate the profile.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#create_time::Google::Protobuf::Timestamp

Returns The time at which the table was created.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#data_risk_level::Google::Cloud::Dlp::V2::DataRiskLevel

Returns The data risk level of this table.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#data_source_type::Google::Cloud::Dlp::V2::DataSourceType

Returns The resource type that was profiled.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#dataset_id::String

Returns If the resource is BigQuery, the dataset ID.

Returns:

  • (::String)

    If the resource is BigQuery, the dataset ID.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#dataset_location::String

Returns If supported, the location where the dataset's data is stored. See https://cloud.google.com/bigquery/docs/locations for supported locations.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#dataset_project_id::String

Returns The Google Cloud project ID that owns the resource.

Returns:

  • (::String)

    The Google Cloud project ID that owns the resource.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#domains::Array<::Google::Cloud::Dlp::V2::Domain>

Returns Domains associated with the profile.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#encryption_status::Google::Cloud::Dlp::V2::EncryptionStatus

Returns How the table is encrypted.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#expiration_time::Google::Protobuf::Timestamp

Returns Optional. The time when this table expires.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#failed_column_count::Integer

Returns The number of columns skipped in the table because of an error.

Returns:

  • (::Integer)

    The number of columns skipped in the table because of an error.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#full_resource::String

Returns The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile. https://cloud.google.com/apis/design/resource_names#full_resource_name.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#last_modified_time::Google::Protobuf::Timestamp

Returns The time when this table was last modified.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#name::String

Returns The name of the profile.

Returns:

  • (::String)

    The name of the profile.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#other_info_types::Array<::Google::Cloud::Dlp::V2::OtherInfoTypeSummary>

Returns Other infoTypes found in this table's data.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#predicted_info_types::Array<::Google::Cloud::Dlp::V2::InfoTypeSummary>

Returns The infoTypes predicted from this table's data.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#profile_last_generated::Google::Protobuf::Timestamp

Returns The last time the profile was generated.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#profile_status::Google::Cloud::Dlp::V2::ProfileStatus

Returns Success or error status from the most recent profile generation attempt. May be empty if the profile is still being generated.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#project_data_profile::String

Returns The resource name of the project data profile for this table.

Returns:

  • (::String)

    The resource name of the project data profile for this table.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

Returns Resources related to this profile.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#resource_labels::Google::Protobuf::Map{::String => ::String}

Returns The labels applied to the resource at the time the profile was generated.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    The labels applied to the resource at the time the profile was generated.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#resource_visibility::Google::Cloud::Dlp::V2::ResourceVisibility

Returns How broadly a resource has been shared.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#row_count::Integer

Returns Number of rows in the table when the profile was generated. This will not be populated for BigLake tables.

Returns:

  • (::Integer)

    Number of rows in the table when the profile was generated. This will not be populated for BigLake tables.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#sample_findings_table::Google::Cloud::Dlp::V2::BigQueryTable

Returns The BigQuery table to which the sample findings are written.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#scanned_column_count::Integer

Returns The number of columns profiled in the table.

Returns:

  • (::Integer)

    The number of columns profiled in the table.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#sensitivity_score::Google::Cloud::Dlp::V2::SensitivityScore

Returns The sensitivity score of this table.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#state::Google::Cloud::Dlp::V2::TableDataProfile::State

Returns State of a profile. This will always be set to DONE when the table data profile is written to another service like BigQuery or Pub/Sub.

Returns:



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#table_id::String

Returns The table ID.

Returns:

  • (::String)

    The table ID.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#table_size_bytes::Integer

Returns The size of the table when the profile was generated.

Returns:

  • (::Integer)

    The size of the table when the profile was generated.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end

#tags::Array<::Google::Cloud::Dlp::V2::Tag>

Returns The tags attached to the table, including any tags attached during profiling. Because tags are attached to Cloud SQL instances rather than Cloud SQL tables, this field is empty for Cloud SQL table profiles.

Returns:

  • (::Array<::Google::Cloud::Dlp::V2::Tag>)

    The tags attached to the table, including any tags attached during profiling. Because tags are attached to Cloud SQL instances rather than Cloud SQL tables, this field is empty for Cloud SQL table profiles.



7553
7554
7555
7556
7557
7558
7559
7560
7561
7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
7572
7573
7574
7575
7576
7577
7578
7579
7580
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7553

class TableDataProfile
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class ResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a profile. New items may be added.
  module State
    # Unused.
    STATE_UNSPECIFIED = 0

    # The profile is currently running. Once a profile has finished it will
    # transition to DONE.
    RUNNING = 1

    # The profile is no longer generating.
    # If profile_status.status.code is 0, the profile succeeded, otherwise, it
    # failed.
    DONE = 2
  end
end