Class: Google::Cloud::Dlp::V2::TransformationErrorHandling

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/privacy/dlp/v2/dlp.rb

Overview

How to handle transformation errors during de-identification. A transformation error occurs when the requested transformation is incompatible with the data. For example, trying to de-identify an IP address using a DateShift transformation would result in a transformation error, since date info cannot be extracted from an IP address. Information about any incompatible transformations, and how they were handled, is returned in the response as part of the TransformationOverviews.

Defined Under Namespace

Classes: LeaveUntransformed, ThrowError

Instance Attribute Summary collapse

Instance Attribute Details

#leave_untransformed::Google::Cloud::Dlp::V2::TransformationErrorHandling::LeaveUntransformed

Returns Ignore errors

Note: The following fields are mutually exclusive: leave_untransformed, throw_error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2742

class TransformationErrorHandling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Throw an error and fail the request when a transformation error occurs.
  class ThrowError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Skips the data without modifying it if the requested transformation would
  # cause an error. For example, if a `DateShift` transformation were applied
  # an an IP address, this mode would leave the IP address unchanged in the
  # response.
  class LeaveUntransformed
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#throw_error::Google::Cloud::Dlp::V2::TransformationErrorHandling::ThrowError

Returns Throw an error

Note: The following fields are mutually exclusive: throw_error, leave_untransformed. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2742

class TransformationErrorHandling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Throw an error and fail the request when a transformation error occurs.
  class ThrowError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Skips the data without modifying it if the requested transformation would
  # cause an error. For example, if a `DateShift` transformation were applied
  # an an IP address, this mode would leave the IP address unchanged in the
  # response.
  class LeaveUntransformed
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end