Class: Google::Cloud::Dlp::V2::VertexDatasetRegexes
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::VertexDatasetRegexes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
A collection of regular expressions to determine what datasets to match against.
Instance Attribute Summary collapse
Instance Attribute Details
#patterns ⇒ ::Array<::Google::Cloud::Dlp::V2::VertexDatasetRegex>
Returns Required. The group of regular expression patterns to match against one or more datasets. Maximum of 100 entries. The sum of the lengths of all regular expressions can't exceed 10 KiB.
6273 6274 6275 6276 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6273 class VertexDatasetRegexes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |