Class: Google::Cloud::Dlp::V2::AdjustByMatchingInfoTypes
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::AdjustByMatchingInfoTypes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
AdjustmentRule condition for matching infoTypes.
Instance Attribute Summary collapse
-
#info_types ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoType>
Sensitive Data Protection adjusts the likelihood of a finding if that finding also matches one of these infoTypes.
-
#matching_type ⇒ ::Google::Cloud::Dlp::V2::MatchingType
How the adjustment rule is applied.
-
#min_likelihood ⇒ ::Google::Cloud::Dlp::V2::Likelihood
Required.
Instance Attribute Details
#info_types ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoType>
Returns Sensitive Data Protection adjusts the likelihood of a finding if that finding also matches one of these infoTypes.
For example, you can create a rule to adjust the likelihood of a
PHONE_NUMBER finding if the string is found within a document that is
classified as DOCUMENT_TYPE/HR/RESUME. To configure this, set
PHONE_NUMBER in InspectionRuleSet.info_types. Add an adjustment_rule
with an adjust_by_matching_info_types.info_types that contains
DOCUMENT_TYPE/HR/RESUME. In this case, the likelihood of the
PHONE_NUMBER finding is adjusted, but the likelihood of the
DOCUMENT_TYPE/HR/RESUME finding is not.
151 152 153 154 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 151 class AdjustByMatchingInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#matching_type ⇒ ::Google::Cloud::Dlp::V2::MatchingType
Returns How the adjustment rule is applied.
Only MATCHING_TYPE_PARTIAL_MATCH is supported:
- Partial match: adjusts the findings of infoTypes specified in the inspection rule when they have a nonempty intersection with a finding of an infoType specified in this adjustment rule.
151 152 153 154 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 151 class AdjustByMatchingInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_likelihood ⇒ ::Google::Cloud::Dlp::V2::Likelihood
Returns Required. Minimum likelihood of the
adjust_by_matching_info_types.info_types finding. If the likelihood is
lower than this value, Sensitive Data Protection doesn't adjust the
likelihood of the InspectionRuleSet.info_types finding.
151 152 153 154 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 151 class AdjustByMatchingInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |