Class: Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::DeltaPresenceEstimationResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::DeltaPresenceEstimationResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Result of the δ-presence computation. Note that these results are an estimation, not exact values.
Defined Under Namespace
Classes: DeltaPresenceEstimationHistogramBucket, DeltaPresenceEstimationQuasiIdValues
Instance Attribute Summary collapse
-
#delta_presence_estimation_histogram ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::DeltaPresenceEstimationResult::DeltaPresenceEstimationHistogramBucket>
The intervals [min_probability, max_probability) do not overlap.
Instance Attribute Details
#delta_presence_estimation_histogram ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::DeltaPresenceEstimationResult::DeltaPresenceEstimationHistogramBucket>
Returns The intervals [min_probability, max_probability) do not overlap. If a value doesn't correspond to any such interval, the associated frequency is zero. For example, the following records: {min_probability: 0, max_probability: 0.1, frequency: 17} {min_probability: 0.2, max_probability: 0.3, frequency: 42} {min_probability: 0.3, max_probability: 0.4, frequency: 99} mean that there are no record with an estimated probability in [0.1, 0.2) nor larger or equal to 0.4.
2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2471 class DeltaPresenceEstimationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A tuple of values for the quasi-identifier columns. # @!attribute [rw] quasi_ids_values # @return [::Array<::Google::Cloud::Dlp::V2::Value>] # The quasi-identifier values. # @!attribute [rw] estimated_probability # @return [::Float] # The estimated probability that a given individual sharing these # quasi-identifier values is in the dataset. This value, typically # called δ, is the ratio between the number of records in the dataset # with these quasi-identifier values, and the total number of individuals # (inside *and* outside the dataset) with these quasi-identifier values. # For example, if there are 15 individuals in the dataset who share the # same quasi-identifier values, and an estimated 100 people in the entire # population with these values, then δ is 0.15. class DeltaPresenceEstimationQuasiIdValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A DeltaPresenceEstimationHistogramBucket message with the following # values: # min_probability: 0.1 # max_probability: 0.2 # frequency: 42 # means that there are 42 records for which δ is in [0.1, 0.2). An # important particular case is when min_probability = max_probability = 1: # then, every individual who shares this quasi-identifier combination is in # the dataset. # @!attribute [rw] min_probability # @return [::Float] # Between 0 and 1. # @!attribute [rw] max_probability # @return [::Float] # Always greater than or equal to min_probability. # @!attribute [rw] bucket_size # @return [::Integer] # Number of records within these probability bounds. # @!attribute [rw] bucket_values # @return [::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::DeltaPresenceEstimationResult::DeltaPresenceEstimationQuasiIdValues>] # Sample of quasi-identifier tuple values in this bucket. The total # number of classes returned per bucket is capped at 20. # @!attribute [rw] bucket_value_count # @return [::Integer] # Total number of distinct quasi-identifier tuple values in this bucket. class DeltaPresenceEstimationHistogramBucket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |