Class: Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KMapEstimationResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KMapEstimationResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Result of the reidentifiability analysis. Note that these results are an estimation, not exact values.
Defined Under Namespace
Classes: KMapEstimationHistogramBucket, KMapEstimationQuasiIdValues
Instance Attribute Summary collapse
-
#k_map_estimation_histogram ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KMapEstimationResult::KMapEstimationHistogramBucket>
The intervals [min_anonymity, max_anonymity] do not overlap.
Instance Attribute Details
#k_map_estimation_histogram ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KMapEstimationResult::KMapEstimationHistogramBucket>
Returns The intervals [min_anonymity, max_anonymity] do not overlap. If a value doesn't correspond to any such interval, the associated frequency is zero. For example, the following records: {min_anonymity: 1, max_anonymity: 1, frequency: 17} {min_anonymity: 2, max_anonymity: 3, frequency: 42} {min_anonymity: 5, max_anonymity: 10, frequency: 99} mean that there are no record with an estimated anonymity of 4, 5, or larger than 10.
2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2413 class KMapEstimationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A tuple of values for the quasi-identifier columns. # @!attribute [rw] quasi_ids_values # @return [::Array<::Google::Cloud::Dlp::V2::Value>] # The quasi-identifier values. # @!attribute [rw] estimated_anonymity # @return [::Integer] # The estimated anonymity for these quasi-identifier values. class KMapEstimationQuasiIdValues include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A KMapEstimationHistogramBucket message with the following values: # min_anonymity: 3 # max_anonymity: 5 # frequency: 42 # means that there are 42 records whose quasi-identifier values correspond # to 3, 4 or 5 people in the overlying population. An important particular # case is when min_anonymity = max_anonymity = 1: the frequency field then # corresponds to the number of uniquely identifiable records. # @!attribute [rw] min_anonymity # @return [::Integer] # Always positive. # @!attribute [rw] max_anonymity # @return [::Integer] # Always greater than or equal to min_anonymity. # @!attribute [rw] bucket_size # @return [::Integer] # Number of records within these anonymity bounds. # @!attribute [rw] bucket_values # @return [::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::KMapEstimationResult::KMapEstimationQuasiIdValues>] # Sample of quasi-identifier tuple values in this bucket. The total # number of classes returned per bucket is capped at 20. # @!attribute [rw] bucket_value_count # @return [::Integer] # Total number of distinct quasi-identifier tuple values in this bucket. class KMapEstimationHistogramBucket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |