Class: Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::LDiversityResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::LDiversityResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Result of the l-diversity computation.
Defined Under Namespace
Classes: LDiversityEquivalenceClass, LDiversityHistogramBucket
Instance Attribute Summary collapse
-
#sensitive_value_frequency_histogram_buckets ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::LDiversityResult::LDiversityHistogramBucket>
Histogram of l-diversity equivalence class sensitive value frequencies.
Instance Attribute Details
#sensitive_value_frequency_histogram_buckets ⇒ ::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::LDiversityResult::LDiversityHistogramBucket>
Returns Histogram of l-diversity equivalence class sensitive value frequencies.
2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2353 class LDiversityResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The set of columns' values that share the same ldiversity value. # @!attribute [rw] quasi_ids_values # @return [::Array<::Google::Cloud::Dlp::V2::Value>] # Quasi-identifier values defining the k-anonymity equivalence # class. The order is always the same as the original request. # @!attribute [rw] equivalence_class_size # @return [::Integer] # Size of the k-anonymity equivalence class. # @!attribute [rw] num_distinct_sensitive_values # @return [::Integer] # Number of distinct sensitive values in this equivalence class. # @!attribute [rw] top_sensitive_values # @return [::Array<::Google::Cloud::Dlp::V2::ValueFrequency>] # Estimated frequencies of top sensitive values. class LDiversityEquivalenceClass include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Histogram of l-diversity equivalence class sensitive value frequencies. # @!attribute [rw] sensitive_value_frequency_lower_bound # @return [::Integer] # Lower bound on the sensitive value frequencies of the equivalence # classes in this bucket. # @!attribute [rw] sensitive_value_frequency_upper_bound # @return [::Integer] # Upper bound on the sensitive value frequencies of the equivalence # classes in this bucket. # @!attribute [rw] bucket_size # @return [::Integer] # Total number of equivalence classes in this bucket. # @!attribute [rw] bucket_values # @return [::Array<::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails::LDiversityResult::LDiversityEquivalenceClass>] # Sample of equivalence classes in this bucket. The total number of # classes returned per bucket is capped at 20. # @!attribute [rw] bucket_value_count # @return [::Integer] # Total number of distinct equivalence classes in this bucket. class LDiversityHistogramBucket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |