Class: Google::Cloud::Dlp::V2::BatchContentLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::BatchContentLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Location within a batch of content.
Instance Attribute Summary collapse
-
#item_index ⇒ ::Integer
Matches an index of a batch item in the batch provided in the request.
Instance Attribute Details
#item_index ⇒ ::Integer
Returns Matches an index of a batch item in the batch provided in the request.
827 828 829 830 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 827 class BatchContentLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |