Class: Google::Cloud::Dlp::V2::BucketingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::BucketingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Generalization function that buckets values based on ranges. The ranges and replacement values are dynamically provided by the user for custom behavior, such as 1-30 -> LOW, 31-65 -> MEDIUM, 66-100 -> HIGH.
This can be used on data of type: number, long, string, timestamp.
If the bound Value type differs from the type of data being transformed, we
will first attempt converting the type of the data to be transformed to match
the type of the bound before comparing.
See
https://cloud.google.com/sensitive-data-protection/docs/concepts-bucketing to
learn more.
Defined Under Namespace
Classes: Bucket
Instance Attribute Summary collapse
Instance Attribute Details
#buckets ⇒ ::Array<::Google::Cloud::Dlp::V2::BucketingConfig::Bucket>
Returns Set of buckets. Ranges must be non-overlapping.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3122 class BucketingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Bucket is represented as a range, along with replacement values. # @!attribute [rw] min # @return [::Google::Cloud::Dlp::V2::Value] # Lower bound of the range, inclusive. Type should be the same as max if # used. # @!attribute [rw] max # @return [::Google::Cloud::Dlp::V2::Value] # Upper bound of the range, exclusive; type must match min. # @!attribute [rw] replacement_value # @return [::Google::Cloud::Dlp::V2::Value] # Required. Replacement value for this bucket. class Bucket include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |