Class: Google::Cloud::Dlp::V2::ColumnDataProfile
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ColumnDataProfile
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
The profile for a scanned column within a table.
Defined Under Namespace
Modules: ColumnDataType, ColumnPolicyState, State
Instance Attribute Summary collapse
-
#column ⇒ ::String
The name of the column.
-
#column_info_type ⇒ ::Google::Cloud::Dlp::V2::InfoTypeSummary
If it's been determined this column can be identified as a single type, this will be set.
-
#column_type ⇒ ::Google::Cloud::Dlp::V2::ColumnDataProfile::ColumnDataType
The data type of a given column.
-
#data_risk_level ⇒ ::Google::Cloud::Dlp::V2::DataRiskLevel
The data risk level for this column.
-
#dataset_id ⇒ ::String
The BigQuery dataset ID, if the resource profiled is a BigQuery table.
-
#dataset_location ⇒ ::String
If supported, the location where the dataset's data is stored.
-
#dataset_project_id ⇒ ::String
The Google Cloud project ID that owns the profiled resource.
-
#estimated_null_percentage ⇒ ::Google::Cloud::Dlp::V2::NullPercentageLevel
Approximate percentage of entries being null in the column.
-
#estimated_uniqueness_score ⇒ ::Google::Cloud::Dlp::V2::UniquenessScoreLevel
Approximate uniqueness of the column.
-
#free_text_score ⇒ ::Float
The likelihood that this column contains free-form text.
-
#name ⇒ ::String
The name of the profile.
-
#other_matches ⇒ ::Array<::Google::Cloud::Dlp::V2::OtherInfoTypeSummary>
Other types found within this column.
-
#policy_state ⇒ ::Google::Cloud::Dlp::V2::ColumnDataProfile::ColumnPolicyState
Indicates if a policy tag has been applied to the column.
-
#profile_last_generated ⇒ ::Google::Protobuf::Timestamp
The last time the profile was generated.
-
#profile_status ⇒ ::Google::Cloud::Dlp::V2::ProfileStatus
Success or error status from the most recent profile generation attempt.
-
#sensitivity_score ⇒ ::Google::Cloud::Dlp::V2::SensitivityScore
The sensitivity of this column.
-
#state ⇒ ::Google::Cloud::Dlp::V2::ColumnDataProfile::State
State of a profile.
-
#table_data_profile ⇒ ::String
The resource name of the table data profile.
-
#table_full_resource ⇒ ::String
The resource name of the resource this column is within.
-
#table_id ⇒ ::String
The table ID.
Instance Attribute Details
#column ⇒ ::String
Returns The name of the column.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#column_info_type ⇒ ::Google::Cloud::Dlp::V2::InfoTypeSummary
Returns If it's been determined this column can be identified as a single type, this will be set. Otherwise the column either has unidentifiable content or mixed types.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#column_type ⇒ ::Google::Cloud::Dlp::V2::ColumnDataProfile::ColumnDataType
Returns The data type of a given column.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#data_risk_level ⇒ ::Google::Cloud::Dlp::V2::DataRiskLevel
Returns The data risk level for this column.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#dataset_id ⇒ ::String
Returns The BigQuery dataset ID, if the resource profiled is a BigQuery table.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#dataset_location ⇒ ::String
Returns If supported, the location where the dataset's data is stored. See https://cloud.google.com/bigquery/docs/locations for supported BigQuery locations.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#dataset_project_id ⇒ ::String
Returns The Google Cloud project ID that owns the profiled resource.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#estimated_null_percentage ⇒ ::Google::Cloud::Dlp::V2::NullPercentageLevel
Returns Approximate percentage of entries being null in the column.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#estimated_uniqueness_score ⇒ ::Google::Cloud::Dlp::V2::UniquenessScoreLevel
Returns Approximate uniqueness of the column.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#free_text_score ⇒ ::Float
Returns The likelihood that this column contains free-form text. A value close to 1 may indicate the column is likely to contain free-form or natural language text. Range in 0-1.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#name ⇒ ::String
Returns The name of the profile.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#other_matches ⇒ ::Array<::Google::Cloud::Dlp::V2::OtherInfoTypeSummary>
Returns Other types found within this column. List will be unordered.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#policy_state ⇒ ::Google::Cloud::Dlp::V2::ColumnDataProfile::ColumnPolicyState
Returns Indicates if a policy tag has been applied to the column.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#profile_last_generated ⇒ ::Google::Protobuf::Timestamp
Returns The last time the profile was generated.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#profile_status ⇒ ::Google::Cloud::Dlp::V2::ProfileStatus
Returns Success or error status from the most recent profile generation attempt. May be empty if the profile is still being generated.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#sensitivity_score ⇒ ::Google::Cloud::Dlp::V2::SensitivityScore
Returns The sensitivity of this column.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#state ⇒ ::Google::Cloud::Dlp::V2::ColumnDataProfile::State
Returns State of a profile.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#table_data_profile ⇒ ::String
Returns The resource name of the table data profile.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#table_full_resource ⇒ ::String
Returns The resource name of the resource this column is within.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |
#table_id ⇒ ::String
Returns The table ID.
7694 7695 7696 7697 7698 7699 7700 7701 7702 7703 7704 7705 7706 7707 7708 7709 7710 7711 7712 7713 7714 7715 7716 7717 7718 7719 7720 7721 7722 7723 7724 7725 7726 7727 7728 7729 7730 7731 7732 7733 7734 7735 7736 7737 7738 7739 7740 7741 7742 7743 7744 7745 7746 7747 7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 7779 7780 7781 7782 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 7694 class ColumnDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a profile. New items may be added. module State # Unused. STATE_UNSPECIFIED = 0 # The profile is currently running. Once a profile has finished it will # transition to DONE. RUNNING = 1 # The profile is no longer generating. # If profile_status.status.code is 0, the profile succeeded, otherwise, it # failed. DONE = 2 end # Data types of the data in a column. Types may be added over time. module ColumnDataType # Invalid type. COLUMN_DATA_TYPE_UNSPECIFIED = 0 # Encoded as a string in decimal format. TYPE_INT64 = 1 # Encoded as a boolean "false" or "true". TYPE_BOOL = 2 # Encoded as a number, or string "NaN", "Infinity" or "-Infinity". TYPE_FLOAT64 = 3 # Encoded as a string value. TYPE_STRING = 4 # Encoded as a base64 string per RFC 4648, section 4. TYPE_BYTES = 5 # Encoded as an RFC 3339 timestamp with mandatory "Z" time zone string: # 1985-04-12T23:20:50.52Z TYPE_TIMESTAMP = 6 # Encoded as RFC 3339 full-date format string: 1985-04-12 TYPE_DATE = 7 # Encoded as RFC 3339 partial-time format string: 23:20:50.52 TYPE_TIME = 8 # Encoded as RFC 3339 full-date "T" partial-time: 1985-04-12T23:20:50.52 TYPE_DATETIME = 9 # Encoded as WKT TYPE_GEOGRAPHY = 10 # Encoded as a decimal string. TYPE_NUMERIC = 11 # Container of ordered fields, each with a type and field name. TYPE_RECORD = 12 # Decimal type. TYPE_BIGNUMERIC = 13 # Json type. TYPE_JSON = 14 # Interval type. TYPE_INTERVAL = 15 # `Range<Date>` type. TYPE_RANGE_DATE = 16 # `Range<Datetime>` type. TYPE_RANGE_DATETIME = 17 # `Range<Timestamp>` type. TYPE_RANGE_TIMESTAMP = 18 end # The possible policy states for a column. module ColumnPolicyState # No policy tags. COLUMN_POLICY_STATE_UNSPECIFIED = 0 # Column has policy tag applied. COLUMN_POLICY_TAGGED = 1 end end |