Class: Google::Cloud::Dlp::V2::ConversationLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ConversationLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Location within a conversation.
Defined Under Namespace
Classes: AllMessages
Instance Attribute Summary collapse
-
#all_messages ⇒ ::Google::Cloud::Dlp::V2::ConversationLocation::AllMessages
If set, indicates that the finding applies to all messages in the conversation.
-
#message_index ⇒ ::Integer
Matches an index of a message in the conversation provided in the request.
Instance Attribute Details
#all_messages ⇒ ::Google::Cloud::Dlp::V2::ConversationLocation::AllMessages
Returns If set, indicates that the finding applies to all messages in the conversation.
Note: The following fields are mutually exclusive: all_messages, message_index. If a field in that set is populated, all other fields in the set will automatically be cleared.
811 812 813 814 815 816 817 818 819 820 821 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 811 class ConversationLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # If set, indicates that the finding applies to all messages in the # conversation. class AllMessages include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#message_index ⇒ ::Integer
Returns Matches an index of a message in the conversation provided in the request.
Note: The following fields are mutually exclusive: message_index, all_messages. If a field in that set is populated, all other fields in the set will automatically be cleared.
811 812 813 814 815 816 817 818 819 820 821 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 811 class ConversationLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # If set, indicates that the finding applies to all messages in the # conversation. class AllMessages include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |