Class: Google::Cloud::Dlp::V2::DataProfilePubSubCondition
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::DataProfilePubSubCondition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
A condition for determining whether a Pub/Sub should be triggered.
Defined Under Namespace
Modules: ProfileScoreBucket Classes: PubSubCondition, PubSubExpressions
Instance Attribute Summary collapse
-
#expressions ⇒ ::Google::Cloud::Dlp::V2::DataProfilePubSubCondition::PubSubExpressions
An expression.
Instance Attribute Details
#expressions ⇒ ::Google::Cloud::Dlp::V2::DataProfilePubSubCondition::PubSubExpressions
Returns An expression.
8206 8207 8208 8209 8210 8211 8212 8213 8214 8215 8216 8217 8218 8219 8220 8221 8222 8223 8224 8225 8226 8227 8228 8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 8252 8253 8254 8255 8256 8257 8258 8259 8260 8261 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8206 class DataProfilePubSubCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A condition consisting of a value. # @!attribute [rw] minimum_risk_score # @return [::Google::Cloud::Dlp::V2::DataProfilePubSubCondition::ProfileScoreBucket] # The minimum data risk score that triggers the condition. # # Note: The following fields are mutually exclusive: `minimum_risk_score`, `minimum_sensitivity_score`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] minimum_sensitivity_score # @return [::Google::Cloud::Dlp::V2::DataProfilePubSubCondition::ProfileScoreBucket] # The minimum sensitivity level that triggers the condition. # # Note: The following fields are mutually exclusive: `minimum_sensitivity_score`, `minimum_risk_score`. If a field in that set is populated, all other fields in the set will automatically be cleared. class PubSubCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An expression, consisting of an operator and conditions. # @!attribute [rw] logical_operator # @return [::Google::Cloud::Dlp::V2::DataProfilePubSubCondition::PubSubExpressions::PubSubLogicalOperator] # The operator to apply to the collection of conditions. # @!attribute [rw] conditions # @return [::Array<::Google::Cloud::Dlp::V2::DataProfilePubSubCondition::PubSubCondition>] # Conditions to apply to the expression. class PubSubExpressions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Logical operators for conditional checks. module PubSubLogicalOperator # Unused. LOGICAL_OPERATOR_UNSPECIFIED = 0 # Conditional OR. OR = 1 # Conditional AND. AND = 2 end end # Various score levels for resources. module ProfileScoreBucket # Unused. PROFILE_SCORE_BUCKET_UNSPECIFIED = 0 # High risk/sensitivity detected. HIGH = 1 # Medium or high risk/sensitivity detected. MEDIUM_OR_HIGH = 2 end end |