Class: Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
How often existing tables should have their profiles refreshed. New tables are scanned as quickly as possible depending on system capacity.
Defined Under Namespace
Classes: SchemaModifiedCadence
Instance Attribute Summary collapse
-
#inspect_template_modified_cadence ⇒ ::Google::Cloud::Dlp::V2::DiscoveryInspectTemplateModifiedCadence
Governs when to update data profiles when the inspection rules defined by the
InspectTemplatechange. -
#refresh_frequency ⇒ ::Google::Cloud::Dlp::V2::DataProfileUpdateFrequency
Data changes (non-schema changes) in Cloud SQL tables can't trigger reprofiling.
-
#schema_modified_cadence ⇒ ::Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence
When to reprofile if the schema has changed.
Instance Attribute Details
#inspect_template_modified_cadence ⇒ ::Google::Cloud::Dlp::V2::DiscoveryInspectTemplateModifiedCadence
Returns Governs when to update data profiles when the inspection rules
defined by the InspectTemplate change.
If not set, changing the template will not cause a data profile to update.
5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 5658 5659 5660 5661 5662 5663 5664 5665 5666 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5637 class DiscoveryCloudSqlGenerationCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How frequently to modify the profile when the table's schema is modified. # @!attribute [rw] types # @return [::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence::CloudSqlSchemaModification>] # The types of schema modifications to consider. # Defaults to NEW_COLUMNS. # @!attribute [rw] frequency # @return [::Google::Cloud::Dlp::V2::DataProfileUpdateFrequency] # Frequency to regenerate data profiles when the schema is modified. # Defaults to monthly. class SchemaModifiedCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of modification that causes a profile update. module CloudSqlSchemaModification # Unused. SQL_SCHEMA_MODIFICATION_UNSPECIFIED = 0 # New columns have appeared. NEW_COLUMNS = 1 # Columns have been removed from the table. REMOVED_COLUMNS = 2 end end end |
#refresh_frequency ⇒ ::Google::Cloud::Dlp::V2::DataProfileUpdateFrequency
Returns Data changes (non-schema changes) in Cloud SQL tables can't trigger reprofiling. If you set this field, profiles are refreshed at this frequency regardless of whether the underlying tables have changed. Defaults to never.
5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 5658 5659 5660 5661 5662 5663 5664 5665 5666 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5637 class DiscoveryCloudSqlGenerationCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How frequently to modify the profile when the table's schema is modified. # @!attribute [rw] types # @return [::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence::CloudSqlSchemaModification>] # The types of schema modifications to consider. # Defaults to NEW_COLUMNS. # @!attribute [rw] frequency # @return [::Google::Cloud::Dlp::V2::DataProfileUpdateFrequency] # Frequency to regenerate data profiles when the schema is modified. # Defaults to monthly. class SchemaModifiedCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of modification that causes a profile update. module CloudSqlSchemaModification # Unused. SQL_SCHEMA_MODIFICATION_UNSPECIFIED = 0 # New columns have appeared. NEW_COLUMNS = 1 # Columns have been removed from the table. REMOVED_COLUMNS = 2 end end end |
#schema_modified_cadence ⇒ ::Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence
Returns When to reprofile if the schema has changed.
5637 5638 5639 5640 5641 5642 5643 5644 5645 5646 5647 5648 5649 5650 5651 5652 5653 5654 5655 5656 5657 5658 5659 5660 5661 5662 5663 5664 5665 5666 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 5637 class DiscoveryCloudSqlGenerationCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # How frequently to modify the profile when the table's schema is modified. # @!attribute [rw] types # @return [::Array<::Google::Cloud::Dlp::V2::DiscoveryCloudSqlGenerationCadence::SchemaModifiedCadence::CloudSqlSchemaModification>] # The types of schema modifications to consider. # Defaults to NEW_COLUMNS. # @!attribute [rw] frequency # @return [::Google::Cloud::Dlp::V2::DataProfileUpdateFrequency] # Frequency to regenerate data profiles when the schema is modified. # Defaults to monthly. class SchemaModifiedCadence include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of modification that causes a profile update. module CloudSqlSchemaModification # Unused. SQL_SCHEMA_MODIFICATION_UNSPECIFIED = 0 # New columns have appeared. NEW_COLUMNS = 1 # Columns have been removed from the table. REMOVED_COLUMNS = 2 end end end |