Class: Google::Cloud::Dlp::V2::DlpJob
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::DlpJob
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Combines all of the information about a DLP job.
Defined Under Namespace
Modules: JobState
Instance Attribute Summary collapse
-
#action_details ⇒ ::Array<::Google::Cloud::Dlp::V2::ActionDetails>
Events that should occur after the job has completed.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
Time when the job was created.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
Time when the job finished.
-
#errors ⇒ ::Array<::Google::Cloud::Dlp::V2::Error>
A stream of errors encountered running the job.
-
#inspect_details ⇒ ::Google::Cloud::Dlp::V2::InspectDataSourceDetails
Results from inspecting a data source.
-
#job_trigger_name ⇒ ::String
If created by a job trigger, the resource name of the trigger that instantiated the job.
-
#last_modified ⇒ ::Google::Protobuf::Timestamp
Time when the job was last modified by the system.
-
#name ⇒ ::String
The server-assigned name.
-
#risk_details ⇒ ::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails
Results from analyzing risk of a data source.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
Time when the job started.
-
#state ⇒ ::Google::Cloud::Dlp::V2::DlpJob::JobState
State of a job.
-
#type ⇒ ::Google::Cloud::Dlp::V2::DlpJobType
The type of job.
Instance Attribute Details
#action_details ⇒ ::Array<::Google::Cloud::Dlp::V2::ActionDetails>
Returns Events that should occur after the job has completed.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp
Returns Time when the job was created.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns Time when the job finished.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#errors ⇒ ::Array<::Google::Cloud::Dlp::V2::Error>
Returns A stream of errors encountered running the job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#inspect_details ⇒ ::Google::Cloud::Dlp::V2::InspectDataSourceDetails
Returns Results from inspecting a data source.
Note: The following fields are mutually exclusive: inspect_details, risk_details. If a field in that set is populated, all other fields in the set will automatically be cleared.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#job_trigger_name ⇒ ::String
Returns If created by a job trigger, the resource name of the trigger that instantiated the job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#last_modified ⇒ ::Google::Protobuf::Timestamp
Returns Time when the job was last modified by the system.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#name ⇒ ::String
Returns The server-assigned name.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#risk_details ⇒ ::Google::Cloud::Dlp::V2::AnalyzeDataSourceRiskDetails
Returns Results from analyzing risk of a data source.
Note: The following fields are mutually exclusive: risk_details, inspect_details. If a field in that set is populated, all other fields in the set will automatically be cleared.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns Time when the job started.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#state ⇒ ::Google::Cloud::Dlp::V2::DlpJob::JobState
Returns State of a job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |
#type ⇒ ::Google::Cloud::Dlp::V2::DlpJobType
Returns The type of job.
6378 6379 6380 6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 6378 class DlpJob include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a job. New items may be added. module JobState # Unused. JOB_STATE_UNSPECIFIED = 0 # The job has not yet started. PENDING = 1 # The job is currently running. Once a job has finished it will transition # to FAILED or DONE. RUNNING = 2 # The job is no longer running. DONE = 3 # The job was canceled before it could be completed. CANCELED = 4 # The job had an error and did not complete. FAILED = 5 # The job is currently accepting findings via hybridInspect. # A hybrid job in ACTIVE state may continue to have findings added to it # through the calling of hybridInspect. After the job has finished no more # calls to hybridInspect may be made. ACTIVE jobs can transition to DONE. ACTIVE = 6 end end |