Class: Google::Cloud::Dlp::V2::Domain
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::Domain
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
A domain represents a thematic category that a data profile can fall under.
Defined Under Namespace
Instance Attribute Summary collapse
-
#category ⇒ ::Google::Cloud::Dlp::V2::Domain::Category
A domain category that this profile is related to.
-
#signals ⇒ ::Array<::Google::Cloud::Dlp::V2::Domain::Signal>
The collection of signals that influenced selection of the category.
Instance Attribute Details
#category ⇒ ::Google::Cloud::Dlp::V2::Domain::Category
Returns A domain category that this profile is related to.
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 8679 8680 8681 8682 8683 8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 8701 8702 8703 8704 8705 8706 8707 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8654 class Domain include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum defines the various domain categories a data profile can fall # under. module Category # Category unspecified. CATEGORY_UNSPECIFIED = 0 # Indicates that the data profile is related to artificial intelligence. # When set, all findings stored to Security Command Center will set the # corresponding AI domain field of `Finding` objects. AI = 1 # Indicates that the data profile is related to code. CODE = 2 end # The signal used to determine the category. # New values may be added in the future. module Signal # Unused. SIGNAL_UNSPECIFIED = 0 # One or more machine learning models are present. MODEL = 1 # A table appears to contain text embeddings. TEXT_EMBEDDING = 2 # A table appears to contain embeddings of any type (for example, text, # image, multimodal). The `TEXT_EMBEDDING` signal might also be present if # the table contains text embeddings. EMBEDDING = 7 # The [Cloud SQL Vertex # AI](https://cloud.google.com/sql/docs/postgres/integrate-cloud-sql-with-vertex-ai) # plugin is installed on the database. VERTEX_PLUGIN = 3 # Support for [Cloud SQL vector # embeddings](https://cloud.google.com/sql/docs/mysql/enable-vector-search) # is enabled on the database. VECTOR_PLUGIN = 4 # Source code is present. SOURCE_CODE = 5 # If the service determines the category type. For example, Vertex AI # assets would always have a `Category` of `AI`. SERVICE = 6 end end |
#signals ⇒ ::Array<::Google::Cloud::Dlp::V2::Domain::Signal>
Returns The collection of signals that influenced selection of the category.
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 8679 8680 8681 8682 8683 8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 8701 8702 8703 8704 8705 8706 8707 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8654 class Domain include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # This enum defines the various domain categories a data profile can fall # under. module Category # Category unspecified. CATEGORY_UNSPECIFIED = 0 # Indicates that the data profile is related to artificial intelligence. # When set, all findings stored to Security Command Center will set the # corresponding AI domain field of `Finding` objects. AI = 1 # Indicates that the data profile is related to code. CODE = 2 end # The signal used to determine the category. # New values may be added in the future. module Signal # Unused. SIGNAL_UNSPECIFIED = 0 # One or more machine learning models are present. MODEL = 1 # A table appears to contain text embeddings. TEXT_EMBEDDING = 2 # A table appears to contain embeddings of any type (for example, text, # image, multimodal). The `TEXT_EMBEDDING` signal might also be present if # the table contains text embeddings. EMBEDDING = 7 # The [Cloud SQL Vertex # AI](https://cloud.google.com/sql/docs/postgres/integrate-cloud-sql-with-vertex-ai) # plugin is installed on the database. VERTEX_PLUGIN = 3 # Support for [Cloud SQL vector # embeddings](https://cloud.google.com/sql/docs/mysql/enable-vector-search) # is enabled on the database. VECTOR_PLUGIN = 4 # Source code is present. SOURCE_CODE = 5 # If the service determines the category type. For example, Vertex AI # assets would always have a `Category` of `AI`. SERVICE = 6 end end |