Module: Google::Cloud::Dlp::V2::Domain::Signal
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
The signal used to determine the category. New values may be added in the future.
Constant Summary collapse
- SIGNAL_UNSPECIFIED =
Unused.
0- MODEL =
One or more machine learning models are present.
1- TEXT_EMBEDDING =
A table appears to contain text embeddings.
2- EMBEDDING =
A table appears to contain embeddings of any type (for example, text, image, multimodal). The
TEXT_EMBEDDINGsignal might also be present if the table contains text embeddings. 7- VERTEX_PLUGIN =
The Cloud SQL Vertex AI plugin is installed on the database.
3- VECTOR_PLUGIN =
Support for Cloud SQL vector embeddings is enabled on the database.
4- SOURCE_CODE =
Source code is present.
5- SERVICE =
If the service determines the category type. For example, Vertex AI assets would always have a
CategoryofAI. 6