Class: Google::Cloud::Dlp::V2::FileClusterType
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::FileClusterType
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Message used to identify file cluster type being profiled.
Defined Under Namespace
Modules: Cluster
Instance Attribute Summary collapse
Instance Attribute Details
#cluster ⇒ ::Google::Cloud::Dlp::V2::FileClusterType::Cluster
Returns Cluster type.
8537 8538 8539 8540 8541 8542 8543 8544 8545 8546 8547 8548 8549 8550 8551 8552 8553 8554 8555 8556 8557 8558 8559 8560 8561 8562 8563 8564 8565 8566 8567 8568 8569 8570 8571 8572 8573 8574 8575 8576 8577 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8537 class FileClusterType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Cluster type. Each cluster corresponds to a set of file types. # Over time, new types may be added and files may move between clusters. module Cluster # Unused. CLUSTER_UNSPECIFIED = 0 # Unsupported files. CLUSTER_UNKNOWN = 1 # Plain text. CLUSTER_TEXT = 2 # Structured data like CSV, TSV etc. CLUSTER_STRUCTURED_DATA = 3 # Source code. CLUSTER_SOURCE_CODE = 4 # Rich document like docx, xlsx etc. CLUSTER_RICH_DOCUMENT = 5 # Images like jpeg, bmp. CLUSTER_IMAGE = 6 # Archives and containers like .zip, .tar etc. CLUSTER_ARCHIVE = 7 # Multimedia like .mp4, .avi etc. CLUSTER_MULTIMEDIA = 8 # Executable files like .exe, .class, .apk etc. CLUSTER_EXECUTABLE = 9 # AI models like .tflite etc. CLUSTER_AI_MODEL = 10 end end |