Class: Google::Cloud::Dlp::V2::FileClusterType
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::FileClusterType
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Message used to identify file cluster type being profiled.
Defined Under Namespace
Modules: Cluster
Instance Attribute Summary collapse
Instance Attribute Details
#cluster ⇒ ::Google::Cloud::Dlp::V2::FileClusterType::Cluster
Returns Cluster type.
8391 8392 8393 8394 8395 8396 8397 8398 8399 8400 8401 8402 8403 8404 8405 8406 8407 8408 8409 8410 8411 8412 8413 8414 8415 8416 8417 8418 8419 8420 8421 8422 8423 8424 8425 8426 8427 8428 8429 8430 8431 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8391 class FileClusterType include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Cluster type. Each cluster corresponds to a set of file types. # Over time, new types may be added and files may move between clusters. module Cluster # Unused. CLUSTER_UNSPECIFIED = 0 # Unsupported files. CLUSTER_UNKNOWN = 1 # Plain text. CLUSTER_TEXT = 2 # Structured data like CSV, TSV etc. CLUSTER_STRUCTURED_DATA = 3 # Source code. CLUSTER_SOURCE_CODE = 4 # Rich document like docx, xlsx etc. CLUSTER_RICH_DOCUMENT = 5 # Images like jpeg, bmp. CLUSTER_IMAGE = 6 # Archives and containers like .zip, .tar etc. CLUSTER_ARCHIVE = 7 # Multimedia like .mp4, .avi etc. CLUSTER_MULTIMEDIA = 8 # Executable files like .exe, .class, .apk etc. CLUSTER_EXECUTABLE = 9 # AI models like .tflite etc. CLUSTER_AI_MODEL = 10 end end |