Class: Google::Cloud::Dlp::V2::ImageTransformations
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ImageTransformations
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
A type of transformation that is applied over images.
Defined Under Namespace
Classes: ImageTransformation
Instance Attribute Summary collapse
-
#transforms ⇒ ::Array<::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation>
List of transforms to make.
Instance Attribute Details
#transforms ⇒ ::Array<::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation>
Returns List of transforms to make.
2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2669 class ImageTransformations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration for determining how redaction of images should occur. # @!attribute [rw] selected_info_types # @return [::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::SelectedInfoTypes] # Apply transformation to the selected info_types. # # Note: The following fields are mutually exclusive: `selected_info_types`, `all_info_types`, `all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] all_info_types # @return [::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::AllInfoTypes] # Apply transformation to all findings not specified in other # ImageTransformation's selected_info_types. Only one instance is allowed # within the ImageTransformations message. # # Note: The following fields are mutually exclusive: `all_info_types`, `selected_info_types`, `all_text`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] all_text # @return [::Google::Cloud::Dlp::V2::ImageTransformations::ImageTransformation::AllText] # Apply transformation to all text that doesn't match an infoType. Only # one instance is allowed within the ImageTransformations message. # # Note: The following fields are mutually exclusive: `all_text`, `selected_info_types`, `all_info_types`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] redaction_color # @return [::Google::Cloud::Dlp::V2::Color] # The color to use when redacting content from an image. If not # specified, the default is black. class ImageTransformation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Apply transformation to the selected info_types. # @!attribute [rw] info_types # @return [::Array<::Google::Cloud::Dlp::V2::InfoType>] # Required. InfoTypes to apply the transformation to. Required. Provided # InfoType must be unique within the ImageTransformations message. class SelectedInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply transformation to all findings. class AllInfoTypes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Apply to all text. class AllText include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |