Class: Google::Cloud::Dlp::V2::InfoTypeDescription
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::InfoTypeDescription
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
InfoType description.
Defined Under Namespace
Modules: InfoTypeLaunchStatus
Instance Attribute Summary collapse
-
#categories ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoTypeCategory>
The category of the infoType.
-
#description ⇒ ::String
Description of the infotype.
-
#display_name ⇒ ::String
Human readable form of the infoType name.
-
#example ⇒ ::String
A sample that is a true positive for this infoType.
-
#launch_status ⇒ ::Google::Cloud::Dlp::V2::InfoTypeDescription::InfoTypeLaunchStatus
The launch status of the infoType.
-
#location_support ⇒ ::Google::Cloud::Dlp::V2::LocationSupport
Locations at which this feature can be used.
-
#name ⇒ ::String
Internal name of the infoType.
-
#sensitivity_score ⇒ ::Google::Cloud::Dlp::V2::SensitivityScore
The default sensitivity of the infoType.
-
#specific_info_types ⇒ ::Array<::String>
If this field is set, this infoType is a general infoType and these specific infoTypes are contained within it.
-
#supported_by ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoTypeSupportedBy>
Which parts of the API supports this InfoType.
-
#versions ⇒ ::Array<::Google::Cloud::Dlp::V2::VersionDescription>
A list of available versions for the infotype.
Instance Attribute Details
#categories ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoTypeCategory>
Returns The category of the infoType.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#description ⇒ ::String
Returns Description of the infotype. Translated when language is provided in the request.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#display_name ⇒ ::String
Returns Human readable form of the infoType name.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#example ⇒ ::String
Returns A sample that is a true positive for this infoType.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#launch_status ⇒ ::Google::Cloud::Dlp::V2::InfoTypeDescription::InfoTypeLaunchStatus
Returns The launch status of the infoType.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#location_support ⇒ ::Google::Cloud::Dlp::V2::LocationSupport
Returns Locations at which this feature can be used. May change over time.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#name ⇒ ::String
Returns Internal name of the infoType.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#sensitivity_score ⇒ ::Google::Cloud::Dlp::V2::SensitivityScore
Returns The default sensitivity of the infoType.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#specific_info_types ⇒ ::Array<::String>
Returns If this field is set, this infoType is a general infoType and these specific infoTypes are contained within it. General infoTypes are infoTypes that encompass multiple specific infoTypes. For example, the "GEOGRAPHIC_DATA" general infoType would have set for this field "LOCATION", "LOCATION_COORDINATES", and "STREET_ADDRESS".
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#supported_by ⇒ ::Array<::Google::Cloud::Dlp::V2::InfoTypeSupportedBy>
Returns Which parts of the API supports this InfoType.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |
#versions ⇒ ::Array<::Google::Cloud::Dlp::V2::VersionDescription>
Returns A list of available versions for the infotype.
1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1609 class InfoTypeDescription include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The launch status of an infoType. module InfoTypeLaunchStatus # Unspecified. INFO_TYPE_LAUNCH_STATUS_UNSPECIFIED = 0 # InfoType is generally available. GENERAL_AVAILABILITY = 1 # InfoType is in public preview. PUBLIC_PREVIEW = 2 # InfoType is in private preview. PRIVATE_PREVIEW = 3 end end |