Class: Google::Cloud::Dlp::V2::InspectDataSourceDetails
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::InspectDataSourceDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
The results of an inspect DataSource job.
Defined Under Namespace
Classes: RequestedOptions, Result
Instance Attribute Summary collapse
-
#requested_options ⇒ ::Google::Cloud::Dlp::V2::InspectDataSourceDetails::RequestedOptions
The configuration used for this job.
-
#result ⇒ ::Google::Cloud::Dlp::V2::InspectDataSourceDetails::Result
A summary of the outcome of this inspection job.
Instance Attribute Details
#requested_options ⇒ ::Google::Cloud::Dlp::V2::InspectDataSourceDetails::RequestedOptions
Returns The configuration used for this job.
1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1405 class InspectDataSourceDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snapshot of the inspection configuration. # @!attribute [rw] snapshot_inspect_template # @return [::Google::Cloud::Dlp::V2::InspectTemplate] # If run with an InspectTemplate, a snapshot of its state at the time of # this run. # @!attribute [rw] job_config # @return [::Google::Cloud::Dlp::V2::InspectJobConfig] # Inspect config. class RequestedOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # All Result fields are updated while the job is processing. # @!attribute [rw] processed_bytes # @return [::Integer] # Total size in bytes that were processed. # @!attribute [rw] total_estimated_bytes # @return [::Integer] # Estimate of the number of bytes to process. # @!attribute [rw] info_type_stats # @return [::Array<::Google::Cloud::Dlp::V2::InfoTypeStats>] # Statistics of how many instances of each info type were found during # inspect job. # @!attribute [rw] num_rows_processed # @return [::Integer] # Number of rows scanned after sampling and time filtering (applicable for # row based stores such as BigQuery). # @!attribute [rw] hybrid_stats # @return [::Google::Cloud::Dlp::V2::HybridInspectStatistics] # Statistics related to the processing of hybrid inspect. class Result include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#result ⇒ ::Google::Cloud::Dlp::V2::InspectDataSourceDetails::Result
Returns A summary of the outcome of this inspection job.
1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 1405 class InspectDataSourceDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Snapshot of the inspection configuration. # @!attribute [rw] snapshot_inspect_template # @return [::Google::Cloud::Dlp::V2::InspectTemplate] # If run with an InspectTemplate, a snapshot of its state at the time of # this run. # @!attribute [rw] job_config # @return [::Google::Cloud::Dlp::V2::InspectJobConfig] # Inspect config. class RequestedOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # All Result fields are updated while the job is processing. # @!attribute [rw] processed_bytes # @return [::Integer] # Total size in bytes that were processed. # @!attribute [rw] total_estimated_bytes # @return [::Integer] # Estimate of the number of bytes to process. # @!attribute [rw] info_type_stats # @return [::Array<::Google::Cloud::Dlp::V2::InfoTypeStats>] # Statistics of how many instances of each info type were found during # inspect job. # @!attribute [rw] num_rows_processed # @return [::Integer] # Number of rows scanned after sampling and time filtering (applicable for # row based stores such as BigQuery). # @!attribute [rw] hybrid_stats # @return [::Google::Cloud::Dlp::V2::HybridInspectStatistics] # Statistics related to the processing of hybrid inspect. class Result include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |