Class: Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Reidentifiability metric. This corresponds to a risk model similar to what is called "journalist risk" in the literature, except the attack dataset is statistically modeled instead of being perfectly known. This can be done using publicly available data (like the US Census), or using a custom statistical model (indicated as one or several BigQuery tables), or by extrapolating from the distribution of values in the input dataset.
Defined Under Namespace
Classes: AuxiliaryTable, TaggedField
Instance Attribute Summary collapse
-
#auxiliary_tables ⇒ ::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::AuxiliaryTable>
Several auxiliary tables can be used in the analysis.
-
#quasi_ids ⇒ ::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::TaggedField>
Required.
-
#region_code ⇒ ::String
ISO 3166-1 alpha-2 region code to use in the statistical modeling.
Instance Attribute Details
#auxiliary_tables ⇒ ::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::AuxiliaryTable>
Returns Several auxiliary tables can be used in the analysis. Each custom_tag used to tag a quasi-identifiers column must appear in exactly one column of one auxiliary table.
2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2117 class KMapEstimationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A column with a semantic tag attached. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Required. Identifies the column. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # A column can be tagged with a InfoType to use the relevant public # dataset as a statistical model of population, if available. We # currently support US ZIP codes, region codes, ages and genders. # To programmatically obtain the list of supported InfoTypes, use # ListInfoTypes with the supported_by=RISK_ANALYSIS filter. # # Note: The following fields are mutually exclusive: `info_type`, `custom_tag`, `inferred`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] custom_tag # @return [::String] # A column can be tagged with a custom tag. In this case, the user must # indicate an auxiliary table that contains statistical information on # the possible values of this column. # # Note: The following fields are mutually exclusive: `custom_tag`, `info_type`, `inferred`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] inferred # @return [::Google::Protobuf::Empty] # If no semantic tag is indicated, we infer the statistical model from # the distribution of values in the input data # # Note: The following fields are mutually exclusive: `inferred`, `info_type`, `custom_tag`. If a field in that set is populated, all other fields in the set will automatically be cleared. class TaggedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An auxiliary table contains statistical information on the relative # frequency of different quasi-identifiers values. It has one or several # quasi-identifiers columns, and one column that indicates the relative # frequency of each quasi-identifier tuple. # If a tuple is present in the data but not in the auxiliary table, the # corresponding relative frequency is assumed to be zero (and thus, the # tuple is highly reidentifiable). # @!attribute [rw] table # @return [::Google::Cloud::Dlp::V2::BigQueryTable] # Required. Auxiliary table location. # @!attribute [rw] quasi_ids # @return [::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::AuxiliaryTable::QuasiIdField>] # Required. Quasi-identifier columns. # @!attribute [rw] relative_frequency # @return [::Google::Cloud::Dlp::V2::FieldId] # Required. The relative frequency column must contain a floating-point # number between 0 and 1 (inclusive). Null values are assumed to be zero. class AuxiliaryTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A quasi-identifier column has a custom_tag, used to know which column # in the data corresponds to which column in the statistical model. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Identifies the column. # @!attribute [rw] custom_tag # @return [::String] # A auxiliary field. class QuasiIdField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#quasi_ids ⇒ ::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::TaggedField>
Returns Required. Fields considered to be quasi-identifiers. No two columns can have the same tag.
2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2117 class KMapEstimationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A column with a semantic tag attached. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Required. Identifies the column. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # A column can be tagged with a InfoType to use the relevant public # dataset as a statistical model of population, if available. We # currently support US ZIP codes, region codes, ages and genders. # To programmatically obtain the list of supported InfoTypes, use # ListInfoTypes with the supported_by=RISK_ANALYSIS filter. # # Note: The following fields are mutually exclusive: `info_type`, `custom_tag`, `inferred`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] custom_tag # @return [::String] # A column can be tagged with a custom tag. In this case, the user must # indicate an auxiliary table that contains statistical information on # the possible values of this column. # # Note: The following fields are mutually exclusive: `custom_tag`, `info_type`, `inferred`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] inferred # @return [::Google::Protobuf::Empty] # If no semantic tag is indicated, we infer the statistical model from # the distribution of values in the input data # # Note: The following fields are mutually exclusive: `inferred`, `info_type`, `custom_tag`. If a field in that set is populated, all other fields in the set will automatically be cleared. class TaggedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An auxiliary table contains statistical information on the relative # frequency of different quasi-identifiers values. It has one or several # quasi-identifiers columns, and one column that indicates the relative # frequency of each quasi-identifier tuple. # If a tuple is present in the data but not in the auxiliary table, the # corresponding relative frequency is assumed to be zero (and thus, the # tuple is highly reidentifiable). # @!attribute [rw] table # @return [::Google::Cloud::Dlp::V2::BigQueryTable] # Required. Auxiliary table location. # @!attribute [rw] quasi_ids # @return [::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::AuxiliaryTable::QuasiIdField>] # Required. Quasi-identifier columns. # @!attribute [rw] relative_frequency # @return [::Google::Cloud::Dlp::V2::FieldId] # Required. The relative frequency column must contain a floating-point # number between 0 and 1 (inclusive). Null values are assumed to be zero. class AuxiliaryTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A quasi-identifier column has a custom_tag, used to know which column # in the data corresponds to which column in the statistical model. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Identifies the column. # @!attribute [rw] custom_tag # @return [::String] # A auxiliary field. class QuasiIdField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#region_code ⇒ ::String
Returns ISO 3166-1 alpha-2 region code to use in the statistical modeling. Set if no column is tagged with a region-specific InfoType (like US_ZIP_5) or a region code.
2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 2117 class KMapEstimationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A column with a semantic tag attached. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Required. Identifies the column. # @!attribute [rw] info_type # @return [::Google::Cloud::Dlp::V2::InfoType] # A column can be tagged with a InfoType to use the relevant public # dataset as a statistical model of population, if available. We # currently support US ZIP codes, region codes, ages and genders. # To programmatically obtain the list of supported InfoTypes, use # ListInfoTypes with the supported_by=RISK_ANALYSIS filter. # # Note: The following fields are mutually exclusive: `info_type`, `custom_tag`, `inferred`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] custom_tag # @return [::String] # A column can be tagged with a custom tag. In this case, the user must # indicate an auxiliary table that contains statistical information on # the possible values of this column. # # Note: The following fields are mutually exclusive: `custom_tag`, `info_type`, `inferred`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] inferred # @return [::Google::Protobuf::Empty] # If no semantic tag is indicated, we infer the statistical model from # the distribution of values in the input data # # Note: The following fields are mutually exclusive: `inferred`, `info_type`, `custom_tag`. If a field in that set is populated, all other fields in the set will automatically be cleared. class TaggedField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An auxiliary table contains statistical information on the relative # frequency of different quasi-identifiers values. It has one or several # quasi-identifiers columns, and one column that indicates the relative # frequency of each quasi-identifier tuple. # If a tuple is present in the data but not in the auxiliary table, the # corresponding relative frequency is assumed to be zero (and thus, the # tuple is highly reidentifiable). # @!attribute [rw] table # @return [::Google::Cloud::Dlp::V2::BigQueryTable] # Required. Auxiliary table location. # @!attribute [rw] quasi_ids # @return [::Array<::Google::Cloud::Dlp::V2::PrivacyMetric::KMapEstimationConfig::AuxiliaryTable::QuasiIdField>] # Required. Quasi-identifier columns. # @!attribute [rw] relative_frequency # @return [::Google::Cloud::Dlp::V2::FieldId] # Required. The relative frequency column must contain a floating-point # number between 0 and 1 (inclusive). Null values are assumed to be zero. class AuxiliaryTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A quasi-identifier column has a custom_tag, used to know which column # in the data corresponds to which column in the statistical model. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Identifies the column. # @!attribute [rw] custom_tag # @return [::String] # A auxiliary field. class QuasiIdField include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |