Class: Google::Cloud::Dlp::V2::ProcessingLocation
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::ProcessingLocation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Configure processing location for discovery and inspection. For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided.
Defined Under Namespace
Classes: DocumentFallbackLocation, GlobalProcessing, ImageFallbackLocation, MultiRegionProcessing
Instance Attribute Summary collapse
-
#document_fallback_location ⇒ ::Google::Cloud::Dlp::V2::ProcessingLocation::DocumentFallbackLocation
Document processing falls back using this configuration.
-
#image_fallback_location ⇒ ::Google::Cloud::Dlp::V2::ProcessingLocation::ImageFallbackLocation
Image processing falls back using this configuration.
Instance Attribute Details
#document_fallback_location ⇒ ::Google::Cloud::Dlp::V2::ProcessingLocation::DocumentFallbackLocation
Returns Document processing falls back using this configuration.
8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 8633 8634 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8588 class ProcessingLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Processing occurs in a multi-region that contains the current region # if available. class MultiRegionProcessing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Processing occurs in the global region. class GlobalProcessing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configure image processing to fall back to any of the following processing # options if image processing is unavailable in the original request # location. # @!attribute [rw] multi_region_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::MultiRegionProcessing] # Processing occurs in a multi-region that contains the current region # if available. # @!attribute [rw] global_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::GlobalProcessing] # Processing occurs in the global region. class ImageFallbackLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configure document processing to fall back to any of the following # processing options if document processing is unavailable in the original # request location. # @!attribute [rw] multi_region_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::MultiRegionProcessing] # Processing occurs in a multi-region that contains the current region # if available. # @!attribute [rw] global_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::GlobalProcessing] # Processing occurs in the global region. class DocumentFallbackLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#image_fallback_location ⇒ ::Google::Cloud::Dlp::V2::ProcessingLocation::ImageFallbackLocation
Returns Image processing falls back using this configuration.
8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 8633 8634 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 8588 class ProcessingLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Processing occurs in a multi-region that contains the current region # if available. class MultiRegionProcessing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Processing occurs in the global region. class GlobalProcessing include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configure image processing to fall back to any of the following processing # options if image processing is unavailable in the original request # location. # @!attribute [rw] multi_region_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::MultiRegionProcessing] # Processing occurs in a multi-region that contains the current region # if available. # @!attribute [rw] global_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::GlobalProcessing] # Processing occurs in the global region. class ImageFallbackLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configure document processing to fall back to any of the following # processing options if document processing is unavailable in the original # request location. # @!attribute [rw] multi_region_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::MultiRegionProcessing] # Processing occurs in a multi-region that contains the current region # if available. # @!attribute [rw] global_processing # @return [::Google::Cloud::Dlp::V2::ProcessingLocation::GlobalProcessing] # Processing occurs in the global region. class DocumentFallbackLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |