Class: Google::Cloud::Dlp::V2::RecordCondition
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::RecordCondition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
A condition for determining whether a transformation should be applied to a field.
Defined Under Namespace
Classes: Condition, Conditions, Expressions
Instance Attribute Summary collapse
Instance Attribute Details
#expressions ⇒ ::Google::Cloud::Dlp::V2::RecordCondition::Expressions
Returns An expression.
3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 3487 3488 3489 3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3452 class RecordCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The field type of `value` and `field` do not need to match to be # considered equal, but not all comparisons are possible. # EQUAL_TO and NOT_EQUAL_TO attempt to compare even with incompatible types, # but all other comparisons are invalid with incompatible types. # A `value` of type: # # - `string` can be compared against all other types # - `boolean` can only be compared against other booleans # - `integer` can be compared against doubles or a string if the string value # can be parsed as an integer. # - `double` can be compared against integers or a string if the string can # be parsed as a double. # - `Timestamp` can be compared against strings in RFC 3339 date string # format. # - `TimeOfDay` can be compared against timestamps and strings in the format # of 'HH:mm:ss'. # # If we fail to compare do to type mismatch, a warning will be given and # the condition will evaluate to false. # @!attribute [rw] field # @return [::Google::Cloud::Dlp::V2::FieldId] # Required. Field within the record this condition is evaluated against. # @!attribute [rw] operator # @return [::Google::Cloud::Dlp::V2::RelationalOperator] # Required. Operator used to compare the field or infoType to the value. # @!attribute [rw] value # @return [::Google::Cloud::Dlp::V2::Value] # Value to compare against. [Mandatory, except for `EXISTS` tests.] class Condition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A collection of conditions. # @!attribute [rw] conditions # @return [::Array<::Google::Cloud::Dlp::V2::RecordCondition::Condition>] # A collection of conditions. class Conditions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # An expression, consisting of an operator and conditions. # @!attribute [rw] logical_operator # @return [::Google::Cloud::Dlp::V2::RecordCondition::Expressions::LogicalOperator] # The operator to apply to the result of conditions. Default and currently # only supported value is `AND`. # @!attribute [rw] conditions # @return [::Google::Cloud::Dlp::V2::RecordCondition::Conditions] # Conditions to apply to the expression. class Expressions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Logical operators for conditional checks. module LogicalOperator # Unused LOGICAL_OPERATOR_UNSPECIFIED = 0 # Conditional AND AND = 1 end end end |