Class: Google::Cloud::Dlp::V2::TransformationSummary
- Inherits:
-
Object
- Object
- Google::Cloud::Dlp::V2::TransformationSummary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/privacy/dlp/v2/dlp.rb
Overview
Summary of a single transformation. Only one of 'transformation', 'field_transformation', or 'record_suppress' will be set.
Defined Under Namespace
Modules: TransformationResultCode Classes: SummaryResult
Instance Attribute Summary collapse
-
#field ⇒ ::Google::Cloud::Dlp::V2::FieldId
Set if the transformation was limited to a specific FieldId.
-
#field_transformations ⇒ ::Array<::Google::Cloud::Dlp::V2::FieldTransformation>
The field transformation that was applied.
-
#info_type ⇒ ::Google::Cloud::Dlp::V2::InfoType
Set if the transformation was limited to a specific InfoType.
-
#record_suppress ⇒ ::Google::Cloud::Dlp::V2::RecordSuppression
The specific suppression option these stats apply to.
-
#results ⇒ ::Array<::Google::Cloud::Dlp::V2::TransformationSummary::SummaryResult>
Collection of all transformations that took place or had an error.
-
#transformation ⇒ ::Google::Cloud::Dlp::V2::PrimitiveTransformation
The specific transformation these stats apply to.
-
#transformed_bytes ⇒ ::Integer
Total size in bytes that were transformed in some way.
Instance Attribute Details
#field ⇒ ::Google::Cloud::Dlp::V2::FieldId
Returns Set if the transformation was limited to a specific FieldId.
3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3559 class TransformationSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection that informs the user the number of times a particular # `TransformationResultCode` and error details occurred. # @!attribute [rw] count # @return [::Integer] # Number of transformations counted by this result. # @!attribute [rw] code # @return [::Google::Cloud::Dlp::V2::TransformationSummary::TransformationResultCode] # Outcome of the transformation. # @!attribute [rw] details # @return [::String] # A place for warnings or errors to show up if a transformation didn't # work as expected. class SummaryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible outcomes of transformations. module TransformationResultCode # Unused TRANSFORMATION_RESULT_CODE_UNSPECIFIED = 0 # Transformation completed without an error. SUCCESS = 1 # Transformation had an error. ERROR = 2 end end |
#field_transformations ⇒ ::Array<::Google::Cloud::Dlp::V2::FieldTransformation>
Returns The field transformation that was applied. If multiple field transformations are requested for a single field, this list will contain all of them; otherwise, only one is supplied.
3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3559 class TransformationSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection that informs the user the number of times a particular # `TransformationResultCode` and error details occurred. # @!attribute [rw] count # @return [::Integer] # Number of transformations counted by this result. # @!attribute [rw] code # @return [::Google::Cloud::Dlp::V2::TransformationSummary::TransformationResultCode] # Outcome of the transformation. # @!attribute [rw] details # @return [::String] # A place for warnings or errors to show up if a transformation didn't # work as expected. class SummaryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible outcomes of transformations. module TransformationResultCode # Unused TRANSFORMATION_RESULT_CODE_UNSPECIFIED = 0 # Transformation completed without an error. SUCCESS = 1 # Transformation had an error. ERROR = 2 end end |
#info_type ⇒ ::Google::Cloud::Dlp::V2::InfoType
Returns Set if the transformation was limited to a specific InfoType.
3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3559 class TransformationSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection that informs the user the number of times a particular # `TransformationResultCode` and error details occurred. # @!attribute [rw] count # @return [::Integer] # Number of transformations counted by this result. # @!attribute [rw] code # @return [::Google::Cloud::Dlp::V2::TransformationSummary::TransformationResultCode] # Outcome of the transformation. # @!attribute [rw] details # @return [::String] # A place for warnings or errors to show up if a transformation didn't # work as expected. class SummaryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible outcomes of transformations. module TransformationResultCode # Unused TRANSFORMATION_RESULT_CODE_UNSPECIFIED = 0 # Transformation completed without an error. SUCCESS = 1 # Transformation had an error. ERROR = 2 end end |
#record_suppress ⇒ ::Google::Cloud::Dlp::V2::RecordSuppression
Returns The specific suppression option these stats apply to.
3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3559 class TransformationSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection that informs the user the number of times a particular # `TransformationResultCode` and error details occurred. # @!attribute [rw] count # @return [::Integer] # Number of transformations counted by this result. # @!attribute [rw] code # @return [::Google::Cloud::Dlp::V2::TransformationSummary::TransformationResultCode] # Outcome of the transformation. # @!attribute [rw] details # @return [::String] # A place for warnings or errors to show up if a transformation didn't # work as expected. class SummaryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible outcomes of transformations. module TransformationResultCode # Unused TRANSFORMATION_RESULT_CODE_UNSPECIFIED = 0 # Transformation completed without an error. SUCCESS = 1 # Transformation had an error. ERROR = 2 end end |
#results ⇒ ::Array<::Google::Cloud::Dlp::V2::TransformationSummary::SummaryResult>
Returns Collection of all transformations that took place or had an error.
3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3559 class TransformationSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection that informs the user the number of times a particular # `TransformationResultCode` and error details occurred. # @!attribute [rw] count # @return [::Integer] # Number of transformations counted by this result. # @!attribute [rw] code # @return [::Google::Cloud::Dlp::V2::TransformationSummary::TransformationResultCode] # Outcome of the transformation. # @!attribute [rw] details # @return [::String] # A place for warnings or errors to show up if a transformation didn't # work as expected. class SummaryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible outcomes of transformations. module TransformationResultCode # Unused TRANSFORMATION_RESULT_CODE_UNSPECIFIED = 0 # Transformation completed without an error. SUCCESS = 1 # Transformation had an error. ERROR = 2 end end |
#transformation ⇒ ::Google::Cloud::Dlp::V2::PrimitiveTransformation
Returns The specific transformation these stats apply to.
3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3559 class TransformationSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection that informs the user the number of times a particular # `TransformationResultCode` and error details occurred. # @!attribute [rw] count # @return [::Integer] # Number of transformations counted by this result. # @!attribute [rw] code # @return [::Google::Cloud::Dlp::V2::TransformationSummary::TransformationResultCode] # Outcome of the transformation. # @!attribute [rw] details # @return [::String] # A place for warnings or errors to show up if a transformation didn't # work as expected. class SummaryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible outcomes of transformations. module TransformationResultCode # Unused TRANSFORMATION_RESULT_CODE_UNSPECIFIED = 0 # Transformation completed without an error. SUCCESS = 1 # Transformation had an error. ERROR = 2 end end |
#transformed_bytes ⇒ ::Integer
Returns Total size in bytes that were transformed in some way.
3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'proto_docs/google/privacy/dlp/v2/dlp.rb', line 3559 class TransformationSummary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A collection that informs the user the number of times a particular # `TransformationResultCode` and error details occurred. # @!attribute [rw] count # @return [::Integer] # Number of transformations counted by this result. # @!attribute [rw] code # @return [::Google::Cloud::Dlp::V2::TransformationSummary::TransformationResultCode] # Outcome of the transformation. # @!attribute [rw] details # @return [::String] # A place for warnings or errors to show up if a transformation didn't # work as expected. class SummaryResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible outcomes of transformations. module TransformationResultCode # Unused TRANSFORMATION_RESULT_CODE_UNSPECIFIED = 0 # Transformation completed without an error. SUCCESS = 1 # Transformation had an error. ERROR = 2 end end |